/*************************************************************************
*
*  History:
*
*	Date 	    Programmer		 	Version			Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	08/07/2014	Sebastian Radau  	1.0.0			Created
*	11/02/2015	Thomas Gertler  	1.0.1			changed namespace creation. added
*													Support for functions in init method.
*													Added getCommandUrl() Method
*	03/07/2015	Thomas Gertler  	1.1.0			Added support for inchorus-gadget-core-1.1
*													contentid is now mandatory for sendCommand() Method
*													Fixed some minor typos
*	10/26/2015	Thomas Gertler		1.1.1			Added support for webcomponents
*	07/15/2016	Thomas Gertler		1.1.2			Finalized Support for webcomponents 1.0.0
*	12/22/2016	Thomas Gertler		1.1.3			added sendPublicCommand function
*	05/12/2020	Thomas Gertler		1.1.4			added support for other gadget init pages as index.html
*																								
*	Copyright (c) G+H Systems GmbH, 2014
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/

var inchorus = inchorus || {};
inchorus.createNS = function (namespace) {
    var nsparts = namespace.split(".");
    var parent = inchorus;
 
    // we want to be able to include or exclude the root namespace so we strip
    // it if it's in the namespace
    if (nsparts[0] === "inchorus") {
        nsparts = nsparts.slice(1);
    }
 
    // loop through the parts and create a nested namespace if necessary
    for (var i = 0; i < nsparts.length; i++) {
        var partname = nsparts[i];
        // check if the current parent already has the namespace declared
        // if it isn't, then create it
        if (typeof parent[partname] === "undefined") {
            parent[partname] = {};
        }
        // get a reference to the deepest element in the hierarchy so far
        parent = parent[partname];
    }
    // the parent is now constructed with empty namespaces and can be used.
    // we return the outermost namespace
    return parent;
};

/*********************************************
 * inchorus gadget functions
 *********************************************/

inchorus.createNS("inchorus.gadget");
	
	inchorus.gadget.init = function (o, success, error) {
		
		if (typeof o.type != 'undefined' && o.type.indexOf('GET') == 0) {
			type = 'GET';
		} else {
			type = 'POST';
		}
		
		if (typeof o.containerid == 'undefined') {
			console.log("inchorus.gadget.init()...[Error - No containerid specified.]");
			return;
		}
		
		if (typeof o.contentid == 'undefined') {
			console.log("inchorus.gadget.init()...[Error - No contentid specified.]");
			return;
		}
		
		if (typeof o.integrationmode == 'undefined') {
			console.log("inchorus.gadget.init()...[Error - No integrationmode specified.]");
			return;
		}
		
		if (typeof o.displaymode == 'undefined') {
			console.log("inchorus.gadget.init()...[Error - No displaymode specified.]");
			return;
		}
		
		if (typeof o.path != 'undefined') {
			//console.log('inchorus.gadget.init()...path specified. we will use path: ' + o.path);
			path = o.path;
		} else {
			//console.log('inchorus.gadget.init()...No path specified. we will use relative path .');
			path = '.';
		}
		
		o.parameter['containerid'] = o.containerid;
		o.parameter['contentid'] = o.contentid;
		o.parameter['integrationmode'] = o.integrationmode;
		o.parameter['displaymode'] = o.displaymode;
		
		jQuery.ajax({
			url: path + '/index.html',
			type: type,
			cache: false,
			data: o.parameter,
			success: function(html){
				if(typeof success == 'function') {
					success(html);
			    } else {
					jQuery('#' + o.containerid + '').html(html);
			    }
			},
			error: function(html) {
				if(typeof error == 'function') {
					error(html);
			    } else {
			    	console.log("inchorus.gadget.init()...[Error - handling ajax call.]");
			    }
			}
		});
	};
	
	inchorus.gadget.getPage = function (o) {
		
		if (typeof o.type != 'undefined' && o.type.indexOf('GET') == 0) {
			type = 'GET';
		} else {
			type = 'POST';
		}
		
		if (typeof o.page == 'undefined') {
			console.log("inchorus.gadget.getPage()...[Error - No page specified.]");
			return;
		}
		
		if (typeof o.path != 'undefined') {
			//console.log('inchorus.gadget.getPage()...path specified. we will use path: ' + o.path);
			path = o.path;
		} else {
			//console.log('inchorus.gadget.getPage()...No path specified. we will use relative path .');
			path = '.';
		}
		
		jQuery.ajax({
			url: path + '/' + o.page,
			cache: false,
			type: type,
			data: o.parameter,
			success: function(html){
				jQuery('#' + o.containerid + '').html(html);
			}
		});
	};
	
	inchorus.gadget.sendCommand = function (o, success, error) {
		
		if (typeof o.type != 'undefined' && o.type.indexOf('GET') == 0) {
			type = 'GET';
		} else {
			type = 'POST';
		}
		
		if (typeof o.command == 'undefined') {
			console.log("inchorus.gadget.sendCommand()...[Error - No command specified.]");
			return;
		}
		
		if (typeof o.contentid == 'undefined') {
			console.log("inchorus.gadget.sendCommand()...[Error - No contentid specified.]");
			return;
		}
		
		if (typeof o.style == 'undefined') {
			console.log("inchorus.gadget.sendCommand()...[Error - No style specified.]");
			return;
		}
		
		o.parameter['command'] = o.command;
		o.parameter['contentid'] = o.contentid;
		o.parameter['style'] = o.style;
		
		if (typeof o.path != 'undefined') {
			//console.log('inchorus.gadget.sendCommand()...path specified. we will use path: ' + o.path);
			path = o.path;
		} else {
			//console.log('inchorus.gadget.sendCommand()...No path specified. we will use relative path .');
			path = '.';
		}
		
		jQuery.ajax({
			url: path + '/command.html',
			cache: false,
			type: type,
			data: o.parameter,
			success: function(html){
				if(typeof success == 'function') {
					success(html);
			    } else {
					jQuery('#' + o.containerid + '').html(html);
			    }
			},
			error: function(html) {
				if(typeof error == 'function') {
					error(html);
			    } else {
			    	console.log("inchorus.gadget.sendCommand()...[Error - handling ajax call.]");
			    }
			}
		});
	};
	
	inchorus.gadget.getCommandUrl = function (o) {
		
		var url = "/command.html";
		
		if (typeof o.path != 'undefined') {
			//console.log('inchorus.gadget.getCommandUrl()...path specified. we will use path: ' + o.path);
			path = o.path;
		} else {
			//console.log('inchorus.gadget.getCommandUrl()...No path specified. we will use relative path .');
			path = '.';
		}
		
		url = path + url;
		
		if (typeof o.command == 'undefined') {
			console.log("inchorus.gadget.getCommandUrl()...[Error - No command specified.]");
			return;
		} else {
			url = url + "?command=" + o.command;
		}
		
		if (typeof o.contentid == 'undefined') {
			console.log("inchorus.gadget.getCommandUrl()...[Error - No contentid specified.]");
			return;
		} else {
			url = url + "&contentid=" + o.contentid;
		}
		
		if (typeof o.style == 'undefined') {
			console.log("inchorus.gadget.getCommandUrl()...[Error - No style specified.]");
			return;
		} else {
			url = url + "&style=" + o.style;
		}
		
		if (typeof o.parameter == 'undefined') {
			//console.log("inchorus.gadget.getCommandUrl()...[No parameter provided.]");
		} else {
			//console.log("inchorus.gadget.getCommandUrl()...[attach parameter to url]");
			for (var key in o.parameter) {
			   var obj = o.parameter[key];
			   url = url + '&' + key + '=' + obj;			   
			}
		}
		return url;
	
	};
	
	
	inchorus.gadget.sendForm = function (o, success, error) {
		
		if (typeof o.formid == 'undefined') {
			console.log("inchorus.gadget.sendForm()...[Error - No formid specified.]");
			return;
		}
		
		if (typeof o.command == 'undefined') {
			console.log("inchorus.gadget.sendForm()...[Error - No command specified.]");
			return;
		} 
		
		if (typeof o.style == 'undefined') {
			console.log("inchorus.gadget.sendForm()...[Error - No style specified.]");
			return;
		}
		
		var formdata = new FormData(document.getElementById(o.formid));
		formdata.append("command", o.command);
		formdata.append("style", o.style);
		
		if (typeof o.path != 'undefined') {
			//console.log('inchorus.gadget.sendForm()...path specified. we will use path: ' + o.path);
			path = o.path;
		} else {
			//console.log('inchorus.gadget.sendForm()...No path specified. we will use relative path .');
			path = '.';
		}
		
		jQuery.ajax({
			url: path + '/command.html',
			cache: false,
			type: 'POST',
			data: formdata,
			enctype: 'multipart/form-data',
    		processData: false,  // tell jQuery not to process the data
    		contentType: false,   // tell jQuery not to set contentType
			success: function(html){
				if(typeof success == 'function') {
					success(html);
			    } else {
					jQuery('#' + o.containerid + '').html(html);
			    }
			},
			error: function(html) {
				if(typeof error == 'function') {
					error(html);
			    } else {
					alert("inchorus.gadget.sendForm() - [Error sending form.]");
			    }
			}
		});
	};
	
	/*********************************************
	 * inchorus webcomponent functions
	 *********************************************/
	
inchorus.createNS("inchorus.$"); // Special namespace for easy usage of the webcomponent functions

	inchorus.$ = function (elementid) {
		var element = document.getElementById(elementid);
		if (element == null) console.log("inchorus.$()...element with id: " + elementid + " not found.");
		return element;
	};
	
	inchorus.$.delay = function (delay, func) {
		setTimeout(
			func, 
			delay
		);
	};

	
inchorus.createNS("inchorus.component"); // namespace for the webcomponent internal functions 
	
	inchorus.component.init = function (element, o, success, error) {
		
		if (typeof o.type != 'undefined' && o.type.indexOf('GET') == 0) {
			type = 'GET';
		} else {
			type = 'POST';
		}
		
		if (typeof o.contentid == 'undefined') {
			console.log("inchorus.component.init()...[Error - No contentid specified.]");
			return;
		}
		
		if (typeof o.integrationmode == 'undefined') {
			console.log("inchorus.component.init()...[Error - No integrationmode specified.]");
			return;
		}
		
		if (typeof o.displaymode == 'undefined') {
			console.log("inchorus.component.init()...[Error - No displaymode specified.]");
			return;
		}
		
		if (typeof o.path != 'undefined') {
			//console.log('inchorus.component.init()...path specified. we will use path: ' + o.path);
			path = o.path;
		} else {
			//console.log('inchorus.component.init()...No path specified. we will use relative path .');
			path = '.';
		}
		
		if (typeof o.initpage == 'undefined') {
			initpage = 'index';
		} else initpage = o.initpage;
		
		o.parameter['contentid'] = o.contentid;
		o.parameter['integrationmode'] = o.integrationmode;
		o.parameter['displaymode'] = o.displaymode;
		
		jQuery.ajax({
			url: path + '/' + initpage + '.html',
			type: type,
			cache: false,
			data: o.parameter,
			success: function(html){
				if(typeof success == 'function') {
					success(html);
			    } else {
			    	if (html) $(element).html(html);
			    }
			},
			error: function(html) {
				if(typeof error == 'function') {
					error(html);
			    } else {
			    	console.log("inchorus.component.init()...[Error - handling ajax call.]");
			    }
			}
		});
	};
	
	inchorus.component.sendCommand = function (element, o, success, error) {
		
		if (typeof o.type != 'undefined' && o.type.indexOf('GET') == 0) {
			type = 'GET';
		} else {
			type = 'POST';
		}
		
		if (typeof o.command == 'undefined') {
			console.log("inchorus.component.sendCommand()...[Error - No command specified.]");
			return;
		}
		
		if (typeof o.contentid == 'undefined') {
			console.log("inchorus.component.sendCommand()...[Error - No contentid specified.]");
			return;
		}
		
		if (typeof o.style == 'undefined') {
			console.log("inchorus.component.sendCommand()...[Error - No style specified.]");
			return;
		}
		
		o.parameter['command'] = o.command;
		o.parameter['contentid'] = o.contentid;
		o.parameter['style'] = o.style;
		
		if (typeof o.path != 'undefined') {
			//console.log('inchorus.component.sendCommand()...path specified. we will use path: ' + o.path);
			path = o.path;
		} else {
			//console.log('inchorus.component.sendCommand()...No path specified. we will use relative path .');
			path = '.';
		}
		
		jQuery.ajax({
			url: path + '/command.html',
			cache: false,
			type: type,
			data: o.parameter,
			success: function(html){
				if(typeof success == 'function') {
					success(html);
			    } else {
			    	if (o.parameter['contentmode'] == 'append') { 
			    		$('inchorus-list-navigation-area').remove();
			    		$('inchorus-list').append(html);
			    	} else {
			    		$(element).html(html);
			    	}
			    }
			},
			error: function(html) {
				if(typeof error == 'function') {
					error(html);
			    } else {
			    	console.log("inchorus.component.sendCommand()...[Error - handling ajax call.]");
			    }
			}
		});
	};
	
	inchorus.component.sendPublicCommand = function (element, o, success, error) {
		
		if (typeof o.type != 'undefined' && o.type.indexOf('GET') == 0) {
			type = 'GET';
		} else {
			type = 'POST';
		}
		
		if (typeof o.command == 'undefined') {
			console.log("inchorus.component.sendPublicCommand()...[Error - No command specified.]");
			return;
		}
		
		if (typeof o.contentid == 'undefined') {
			console.log("inchorus.component.sendPublicCommand()...[Error - No contentid specified.]");
			return;
		}
		
		if (typeof o.style == 'undefined') {
			console.log("inchorus.component.sendPublicCommand()...[Error - No style specified.]");
			return;
		}
		
		o.parameter['command'] = o.command;
		o.parameter['contentid'] = o.contentid;
		o.parameter['style'] = o.style;
		
		if (typeof o.path != 'undefined') {
			//console.log('inchorus.component.sendCommand()...path specified. we will use path: ' + o.path);
			path = o.path;
		} else {
			//console.log('inchorus.component.sendCommand()...No path specified. we will use relative path .');
			path = '.';
		}
		
		jQuery.ajax({
			url: path + '/public.html',
			cache: false,
			type: type,
			data: o.parameter,
			success: function(html){
				if(typeof success == 'function') {
					success(html);
			    } else {
					$(element).html(html);
			    }
			},
			error: function(html) {
				if(typeof error == 'function') {
					error(html);
			    } else {
			    	console.log("inchorus.component.sendPublicCommand()...[Error - handling ajax call.]");
			    }
			}
		});
	};