<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
**************************************************************************
*  
*  History:
*
*	Date 	    Programmer		 	Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/19/2016	Thomas Gertler  	1.2.0		Final 
*												
*	Copyright (c) G+H Systems, 2016	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="datatypes" select="//parameters/parameter[@name='datatypes']" />
		<xsl:variable name="preselect" select="//parameters/parameter[@name='preselect']" />
		<xsl:variable name="preselect_user">status, matched, membership, userroles, userlicenses</xsl:variable>
		<xsl:variable name="preselect_group">category, members</xsl:variable>
		<xsl:variable name="preselect_role">usertoroles, top5roles</xsl:variable>
		<xsl:variable name="preselect_license">usedunused, grouplicenseassignments, top5licenses</xsl:variable>
		
		<xsl:variable name="temp_preselect">
			<xsl:choose>
				<xsl:when test="$preselect != ''">
					<xsl:value-of select="$preselect" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$datatypes = 'user'">
							<xsl:value-of select="$preselect_user" />
						</xsl:when>
						<xsl:when test="$datatypes = 'group'">
							<xsl:value-of select="$preselect_group" />
						</xsl:when>
						<xsl:when test="$datatypes = 'role'">
							<xsl:value-of select="$preselect_role" />
						</xsl:when>
						<xsl:when test="$datatypes = 'license'">
							<xsl:value-of select="$preselect_license" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$preselect" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<div id="multiselect" class="multiselect">
			<div class="selectbox" onclick="showCheckboxes()" style="height: 42px;">
				<select id="configuration-modify-modify-medium-numbers-charts-charttypes-multiselect-selectbox" name="inc-charttype">
					<option id="configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head">
						<xsl:choose>
							<xsl:when test="$datatypes = 'user'">					
								<xsl:attribute name="value"><xsl:value-of select="$temp_preselect"/></xsl:attribute>
								<xsl:choose>
									<xsl:when test="string-length($temp_preselect)-string-length(translate($temp_preselect,',',''))+1 = '1'">
										<xsl:value-of select="$entraid_config_multiselect_charttypes_onechart_part1" />&#160;<xsl:value-of select="string-length($temp_preselect)-string-length(translate($temp_preselect,',',''))+1" />&#160;<xsl:value-of select="$entraid_config_multiselect_charttypes_onechart_part2" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part1" />&#160;<xsl:value-of select="string-length($temp_preselect)-string-length(translate($temp_preselect,',',''))+1" />&#160;<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part2" />
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:when test="$datatypes = 'group'">
								<xsl:attribute name="value"><xsl:value-of select="$temp_preselect"/></xsl:attribute>
								<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part1" />&#160;<xsl:value-of select="string-length($temp_preselect)-string-length(translate($temp_preselect,',',''))+1" />&#160;<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part2" />
							</xsl:when>
							<xsl:when test="$datatypes = 'role'">
								<xsl:attribute name="value"><xsl:value-of select="$temp_preselect"/></xsl:attribute>
								<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part1" />&#160;<xsl:value-of select="string-length($temp_preselect)-string-length(translate($temp_preselect,',',''))+1" />&#160;<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part2" />
							</xsl:when>
							<xsl:when test="$datatypes = 'license'">
								<xsl:attribute name="value"><xsl:value-of select="$temp_preselect"/></xsl:attribute>
								<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part1" />&#160;<xsl:value-of select="string-length($temp_preselect)-string-length(translate($temp_preselect,',',''))+1" />&#160;<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part2" />
							</xsl:when>
						</xsl:choose>
					</option>
				</select>
				<div id="overselect" class="overselect"></div>
			</div>
			<div id="checkboxes-wrapper">
				<inchorus-checkboxes>
					<xsl:attribute name="id">configuration-modify-medium-numbers-charts-charttypes-checkboxes</xsl:attribute>
				    <xsl:attribute name="type">vertical</xsl:attribute>
				    <xsl:attribute name="position">left</xsl:attribute>
				    <xsl:attribute name="hascontentfile">false</xsl:attribute>
				   <xsl:attribute name="onclick">
				    	var temp = '';
				    	var ids = '';
				    	var count = 0;
				    	
				    	$( "#entraid-medium-numbers-charts-charttypes-multiselect-wrapper inchorus-checkboxes input[checked='checked']" ).each(function() {
				    		 if (temp != '') {
							  	ids = ids + ',' + $(this).parent().attr('value');
							  	temp = temp + ', ' + $(this).parent().attr('value');
							  	count = count + 1;
							} else {
							  	ids = $(this).parent().attr('value');
							 	temp = $(this).parent().attr('value');
							 	count = count + 1;
							}
							
							if (count &lt; '2') { 
								$('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').html('<xsl:value-of select="$entraid_config_multiselect_charttypes_onechart_part1" /> 1 <xsl:value-of select="$entraid_config_multiselect_charttypes_onechart_part2" />');
								$('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').val(temp);
							} else {
								$('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').html('<xsl:value-of select="$entraid_config_multiselect_charttypes_header_part1" /> ' + count + ' <xsl:value-of select="$entraid_config_multiselect_charttypes_header_part2" />');
								$('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').val(temp);							
							}
							
				    	});	
				    	
				    	if (count == '') {
				    		$('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').html('<xsl:value-of select="$entraid_config_multiselect_charttypes_nochartselected" />');
							$('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').val(temp);
				    	}
				    	var temp = $('#configuration-modify-medium-numbers-charts-charttypes-multiselect-selectbox-head').val();
				    	$('#datatypes').val($('#entraid-medium-numbers-charts-datatype select').val());
				    	$('#charttypes').val(temp);
				    	inchorus.$('modus-select').setCheckeditemid('modus-select-medium-numbers-charts');
				    	$("#gs-w").val("8"); 
						$("#gs-h").val("4");
					</xsl:attribute>
								
					<xsl:choose>
						<xsl:when test="$datatypes = 'user'">   
							<inchorus-checkbox>
								<xsl:attribute name="id">charttypes-status</xsl:attribute>
							    <xsl:attribute name="name">charttype-status</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_user_status"/></xsl:attribute>
							    <xsl:attribute name="value">status</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'status')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-matched</xsl:attribute>
							    <xsl:attribute name="name">charttype-matched</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_user_matched"/></xsl:attribute>
							    <xsl:attribute name="value">matched</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'matched')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <!-- 
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-login</xsl:attribute>
							    <xsl:attribute name="name">charttype-login</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_user_login"/></xsl:attribute>
							    <xsl:attribute name="value">login</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'login')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 -->
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-membership</xsl:attribute>
							    <xsl:attribute name="name">charttype-membership</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_user_membership"/></xsl:attribute>
							    <xsl:attribute name="value">membership</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'membership')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-userroles</xsl:attribute>
							    <xsl:attribute name="name">charttype-userroles</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_user_roles"/></xsl:attribute>
							    <xsl:attribute name="value">userroles</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'userroles')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-userlicenses</xsl:attribute>
							    <xsl:attribute name="name">charttype-userlicenses</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_user_licenses"/></xsl:attribute>
							    <xsl:attribute name="value">userlicenses</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'userlicenses')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
						</xsl:when>
						<xsl:when test="$datatypes = 'group'">
							<inchorus-checkbox>
								<xsl:attribute name="id">charttypes-category</xsl:attribute>
							    <xsl:attribute name="name">charttype-category</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_group_category"/></xsl:attribute>
							    <xsl:attribute name="value">category</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'category')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-members</xsl:attribute>
							    <xsl:attribute name="name">charttype-members</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_group_members"/></xsl:attribute>
							    <xsl:attribute name="value">members</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'members')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
						</xsl:when>
						<xsl:when test="$datatypes = 'role'">
							<inchorus-checkbox>
								<xsl:attribute name="id">charttypes-usertoroles</xsl:attribute>
							    <xsl:attribute name="name">charttype-usertoroles</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_role_usertoroles"/></xsl:attribute>
							    <xsl:attribute name="value">usertoroles</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'usertoroles')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-top5roles</xsl:attribute>
							    <xsl:attribute name="name">charttype-top5roles</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_role_top5roles"/></xsl:attribute>
							    <xsl:attribute name="value">top5roles</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'top5roles')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <!-- 
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-rolesexpires</xsl:attribute>
							    <xsl:attribute name="name">charttype-rolesexpires</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_role_rolesexpires"/></xsl:attribute>
							    <xsl:attribute name="value">rolesexpires</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'rolesexpires')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 -->
						</xsl:when>
						<xsl:when test="$datatypes = 'license'">
							<inchorus-checkbox>
								<xsl:attribute name="id">charttypes-usedunused</xsl:attribute>
							    <xsl:attribute name="name">charttype-usedunused</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_license_usedunused"/></xsl:attribute>
							    <xsl:attribute name="value">usedunused</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'usedunused')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-grouplicenseassignments</xsl:attribute>
							    <xsl:attribute name="name">charttype-grouplicenseassignments</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_license_grouplicenseassignments"/></xsl:attribute>
							    <xsl:attribute name="value">grouplicenseassignments</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'grouplicenseassignments')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 <!-- 
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-licenseexpires</xsl:attribute>
							    <xsl:attribute name="name">charttype-licenseexpires</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_license_licenseexpires"/></xsl:attribute>
							    <xsl:attribute name="value">licenseexpires</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'licenseexpires')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
							 -->
							 <inchorus-checkbox>
								<xsl:attribute name="id">charttypes-top5licenses</xsl:attribute>
							    <xsl:attribute name="name">charttype-top5licenses</xsl:attribute>
							    <xsl:attribute name="text"><xsl:value-of select="$entraid_config_multiselect_charttypes_license_top5licenses"/></xsl:attribute>
							    <xsl:attribute name="value">top5licenses</xsl:attribute>
							    <xsl:attribute name="preselect"><xsl:value-of select="contains($temp_preselect,'top5licenses')" /></xsl:attribute>
							    <xsl:attribute name="onclick"></xsl:attribute>
							 </inchorus-checkbox>
						</xsl:when>
					</xsl:choose>
				</inchorus-checkboxes>
			</div>
		</div>
		
		
		<script>
			var expanded = false;
			function showCheckboxes() {
				var checkboxes = document.getElementById("checkboxes-wrapper");
				if (!expanded) {
					checkboxes.style.display = "block";
					expanded = true;
				} else {
					checkboxes.style.display = "none";
					expanded = false;
				}
			}
			
			$(document).click(function(event) { 
			  $target = $(event.target);
			
			  if($target.closest('#multiselect').length == '0' &#38;&#38; $('#checkboxes-wrapper').is(":visible") == true) {
			  	showCheckboxes();
			  }
			});
			
		</script>

	</xsl:template>
</xsl:stylesheet>