<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">entraid-licenses-overview</xsl:variable>
		<xsl:variable name="licenseplancount" select="//countsummary/counts/licenseplancount" />
		<xsl:variable name="licenseplanaddcount" select="//countsummary/counts/historycounts/historycount/licenseplanaddcount" />
		<xsl:variable name="licenseplandeletecount" select="//countsummary/counts/historycounts/historycount/licenseplandeletecount" />
		<xsl:variable name="charttypes" select="//parameters/parameter[@name='charttypes']" />

		<div class="entraid-overview-image entraid-overview-image-licenses">
			<xsl:attribute name="onclick">
				window.location.href = 'entraid.html?tab=admin&amp;view=licenses-list';
			</xsl:attribute>
			<xsl:attribute name="title"><xsl:value-of select="$entraid_dashboard_title_alllicenses_part1"/>&#160;<xsl:value-of select="$licenseplancount" />&#160;<xsl:value-of select="$entraid_dashboard_title_alllicenses_part2"/></xsl:attribute>
		</div>

		<div class="entraid-overview-wrapper">
			<div class="entraid-overview-wrapper-numbers">
				<xsl:attribute name="title"><xsl:value-of select="$entraid_dashboard_title_alllicenses_part1"/>&#160;<xsl:value-of select="$licenseplancount" />&#160;<xsl:value-of select="$entraid_dashboard_title_alllicenses_part2"/></xsl:attribute>
				<div class="entraid-overview-wrapper-numbers-licensecount">
					<xsl:attribute name="onclick">
						window.location.href = 'entraid.html?tab=admin&amp;view=license-list';
					</xsl:attribute>
					<xsl:call-template name="format-longnumber">
						<xsl:with-param name="number" select="$licenseplancount"/>
					</xsl:call-template>
				</div>
				<div class="entraid-overview-wrapper-numbers-historycounts">
					<span class="entraid-overview-wrapper-numbers-historycounts-minus">
						<xsl:attribute name="onclick">
							window.location.href = 'entraid.html?tab=admin&amp;view=license-history-list';
						</xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="$entraid_dashboard_title_licensedeletecount_part1" />&#160;<xsl:value-of select="$licenseplandeletecount" />&#160;<xsl:value-of select="$entraid_dashboard_title_licensedeletecount_part2" /></xsl:attribute>
						-<xsl:call-template name="format-longnumber">
							<xsl:with-param name="number" select="$licenseplandeletecount"/>
						</xsl:call-template>
						</span> | <span class="entraid-overview-wrapper-numbers-historycounts-plus">
						<xsl:attribute name="onclick">
							window.location.href = 'entraid.html?tab=admin&amp;view=group-history-list';
						</xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="$entraid_dashboard_title_licenseaddcount_part1" />&#160;<xsl:value-of select="$licenseplanaddcount" />&#160;<xsl:value-of select="$entraid_dashboard_title_licenseaddcount_part2" /></xsl:attribute>
						+<xsl:call-template name="format-longnumber">
							<xsl:with-param name="number" select="$licenseplanaddcount"/>
						</xsl:call-template>						
					</span>
				</div>
			</div>
			<div class="entraid-licenses-overview-smallnumbers-headline">
				<xsl:value-of select="$entraid_dashboard_subtitle_licenses" />
			</div>
		</div>
	</xsl:template>
	
	<xsl:template name="format-longnumber">
	    <xsl:param name="number"/>
	    <xsl:choose>
	      <xsl:when test="$number &lt; '10000'">
	        	<xsl:value-of select="$number"/>
	      </xsl:when>
	      <xsl:when test="$number &lt; '100000'">
	        	<xsl:value-of select="substring($number,1,2)"/>.<xsl:value-of select="substring($number,3,1)"/>k
	      </xsl:when>
	      <xsl:when test="$number = '100000'">
	        	<xsl:value-of select="substring($number,1,2)"/>k
	      </xsl:when>
	      <xsl:when test="$number &lt; '1000000'">
	        	<xsl:value-of select="substring($number,1,3)"/>.<xsl:value-of select="substring($number,4,1)"/>k
	      </xsl:when>
	      <xsl:when test="$number &lt; '1100000'">
	        	1M
	      </xsl:when>
	      <xsl:when test="$number &lt; '10000000'">
	        	<xsl:value-of select="substring($number,1,1)"/>.<xsl:value-of select="substring($number,2,1)"/>M
	      </xsl:when>
	      <xsl:when test="$number &lt; '100000000'">
	        	<xsl:value-of select="substring($number,1,2)"/>.<xsl:value-of select="substring($number,3,1)"/>M
	      </xsl:when>
	      <xsl:when test="$number &lt; '1000000000'">
	        	<xsl:value-of select="substring($number,1,3)"/>M
	      </xsl:when>
	      <xsl:when test="$number &gt;= '1000000000'">
	        	<xsl:value-of select="$number"/>
	      </xsl:when>
	      <xsl:otherwise>
	        	<xsl:value-of select="$number"/>
	      </xsl:otherwise>
	    </xsl:choose>
	</xsl:template>	
	
</xsl:stylesheet>