<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity
*	05/01/2020	Thomas Gertler  	2.1.0		compatible to framework version 2.1 
*												
*	Copyright (c) G+H Systems GmbH, 2020
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->
	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language-webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="thisid">index</xsl:variable>
		<xsl:variable name="parentid">entraid</xsl:variable>
		<xsl:variable name="configurationmode" select="//data/parameters/parameter[@name='configurationmode']/text()"/>
		<xsl:variable name="contentcontainerid" select="//data/parameters/parameter[@name='contentcontainerid']"/>
		<xsl:variable name="contentvariationid" select="//data/parameters/parameter[@name='contentvariationid']/text()"/>
		<xsl:variable name="datatype" select="//data/parameters/parameter[@name='datatypes']/text()"/>
		
		<xsl:variable name="mode" select="//data/parameters/parameter[@name='mode']/text()"/>
		<xsl:variable name="datatypes" select="//data/parameters/parameter[@name='datatypes']/text()"/>
		<xsl:variable name="charttypes" select="//data/parameters/parameter[@name='charttypes']/text()"/>
		
		<xsl:choose>
			<xsl:when test="$configurationmode='add'">
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.entraid.css" />
			
				<div>
					<xsl:attribute name="id"><xsl:value-of select="$parentid" />-add-content</xsl:attribute>
					<xsl:attribute name="class">add-content-list</xsl:attribute>
					<xsl:attribute name="onclick">
						$('#contentcontainer-dashboard-edit-lightbox-add-container').hide();
						$('.add-content-list.active').removeClass('active');
						$(".configuration-add-content-config").each(function( index ) {
							inchorus.$($(this).attr("id")).deactivate();
						});
						$('#<xsl:value-of select="$parentid" />-add-content').addClass('active');
						inchorus.$('<xsl:value-of select="$parentid"/>-add-content-config-<xsl:value-of select="$contentvariationid"/>').activate();									
					</xsl:attribute>
					<div>
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-add-content-image</xsl:attribute>
					</div>
					<b>
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-add-content-text</xsl:attribute>
						<xsl:value-of select="$entraid_add_text" />
					</b>
				</div>
					
				<inchorus-content>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-add-content-config-<xsl:value-of select="$contentvariationid"/></xsl:attribute>
					<xsl:attribute name="active">false</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">configuration-modify</xsl:attribute>	
	 				<xsl:attribute name="parameters">[{"configurationmode":"<xsl:value-of select="$configurationmode"/>"},{"contentcontainerid":"<xsl:value-of select="$contentcontainerid"/>"},{"contentvariationid":"<xsl:value-of select="$contentvariationid"/>"}]</xsl:attribute>
					<xsl:attribute name="class">configuration-add-content-config</xsl:attribute>
				</inchorus-content>
			
			</xsl:when>
			
			<xsl:when test="$configurationmode='edit'">
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.entraid.css" />
				
				<xsl:choose>	
					<xsl:when test="$mode='small_numbers'">
						<div class="daccord-dashboard-edit-box">	
							<div class="daccord-dashboard-edit-box-buttons">
								<inchorus-button>
									<xsl:attribute name="id"><xsl:value-of select="$parentid" />-edit-button-config</xsl:attribute>
									<xsl:attribute name="type">icon</xsl:attribute>
									<xsl:attribute name="icon">config</xsl:attribute>
									<xsl:attribute name="title"><xsl:value-of select="$entraid_config_button_customize" /></xsl:attribute>
									<xsl:attribute name="onclick">
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/>').setParameters(
											{
												"mode":"<xsl:value-of select="$mode" />",
												"datatypes": "<xsl:value-of select="$datatypes" />",
												"configurationmode":"<xsl:value-of select="$configurationmode"/>",
												"contentcontainerid":"<xsl:value-of select="$contentcontainerid"/>",
												"contentvariationid":"<xsl:value-of select="$contentvariationid"/>"
											}
										);
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/>').activate();
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-lightbox-config-<xsl:value-of select="$contentvariationid"/>').activate();									
									</xsl:attribute>
									<xsl:attribute name="highlighting">medium</xsl:attribute>
									<xsl:attribute name="class">dac-dashboard-edit-button-config</xsl:attribute>
								</inchorus-button>
								
								<inchorus-button>
									<xsl:attribute name="id"><xsl:value-of select="$parentid" />-delete-button-delete</xsl:attribute>
									<xsl:attribute name="type">icon</xsl:attribute>
									<xsl:attribute name="icon">delete</xsl:attribute>
									<xsl:attribute name="title"><xsl:value-of select="$entraid_config_button_remove" /></xsl:attribute>
									<xsl:attribute name="onclick">
										inchorus.$('<xsl:value-of select="$parentid"/>-delete-lightbox-config-<xsl:value-of select="$contentvariationid"/>').activate();									
									</xsl:attribute>
									<xsl:attribute name="highlighting">medium</xsl:attribute>
									<xsl:attribute name="class">dac-dashboard-edit-button-delete</xsl:attribute>
								</inchorus-button>
							</div>
							<div style="overflow:hidden;">
								<div>	
									<xsl:choose>
										<xsl:when test="$datatype = 'user'">
											<xsl:attribute name="class">entraid-dashboard-image-small-numbers-users</xsl:attribute>
										</xsl:when>
										<xsl:when test="$datatype = 'group'">
											<xsl:attribute name="class">entraid-dashboard-image-small-numbers-groups</xsl:attribute>
										</xsl:when>
										<xsl:when test="$datatype = 'role'">
											<xsl:attribute name="class">entraid-dashboard-image-small-numbers-roles</xsl:attribute>
										</xsl:when>
										<xsl:when test="$datatype = 'license'">
											<xsl:attribute name="class">entraid-dashboard-image-small-numbers-licenses</xsl:attribute>
										</xsl:when>
									</xsl:choose>
								</div>
								<div>
									<xsl:choose>
										<xsl:when test="$datatype = 'user'">
											<xsl:attribute name="class">entraid-dashboard-text-small-numbers-users</xsl:attribute>
											<xsl:value-of select="$entraid_config_modus_text_users" />
										</xsl:when>
										<xsl:when test="$datatype = 'group'">
											<xsl:attribute name="class">entraid-dashboard-text-small-numbers-groups</xsl:attribute>
											<xsl:value-of select="$entraid_config_modus_text_groups" />
										</xsl:when>
										<xsl:when test="$datatype = 'role'">
											<xsl:attribute name="class">entraid-dashboard-text-small-numbers-roles</xsl:attribute>
											<xsl:value-of select="$entraid_config_modus_text_roles" />
										</xsl:when>
										<xsl:when test="$datatype = 'license'">
											<xsl:attribute name="class">entraid-dashboard-text-small-numbers-licenses</xsl:attribute>
											<xsl:value-of select="$entraid_config_modus_text_licenses" />
										</xsl:when>
									</xsl:choose>
								</div>
							</div>
						</div>
					</xsl:when>
					
					
					<xsl:when test="$mode='medium_numbers_charts'">
						<div class="daccord-dashboard-edit-box">	
							<div class="daccord-dashboard-edit-box-buttons">
								<inchorus-button>
									<xsl:attribute name="id"><xsl:value-of select="$parentid" />-edit-button-config</xsl:attribute>
									<xsl:attribute name="type">icon</xsl:attribute>
									<xsl:attribute name="icon">config</xsl:attribute>
									<xsl:attribute name="title"><xsl:value-of select="$entraid_config_button_customize" /></xsl:attribute>
									<xsl:attribute name="onclick">
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/>').setParameters(
											{
												"mode":"<xsl:value-of select="$mode" />",
												"datatypes": "<xsl:value-of select="$datatypes" />",
												"charttypes":"<xsl:value-of select="$charttypes" />",
												"configurationmode":"<xsl:value-of select="$configurationmode"/>",
												"contentcontainerid":"<xsl:value-of select="$contentcontainerid"/>",
												"contentvariationid":"<xsl:value-of select="$contentvariationid"/>"
											}
										);
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/>').activate();
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-lightbox-config-<xsl:value-of select="$contentvariationid"/>').activate();									
									</xsl:attribute>
									<xsl:attribute name="highlighting">medium</xsl:attribute>
									<xsl:attribute name="class">dac-dashboard-edit-button-config</xsl:attribute>
								</inchorus-button>
								
								<inchorus-button>
									<xsl:attribute name="id"><xsl:value-of select="$parentid" />-delete-button-delete</xsl:attribute>
									<xsl:attribute name="type">icon</xsl:attribute>
									<xsl:attribute name="icon">delete</xsl:attribute>
									<xsl:attribute name="title"><xsl:value-of select="$entraid_config_button_remove" /></xsl:attribute>
									<xsl:attribute name="onclick">
										inchorus.$('<xsl:value-of select="$parentid"/>-delete-lightbox-config-<xsl:value-of select="$contentvariationid"/>').activate();									
									</xsl:attribute>
									<xsl:attribute name="highlighting">medium</xsl:attribute>
									<xsl:attribute name="class">dac-dashboard-edit-button-delete</xsl:attribute>
								</inchorus-button>
							</div>
							<div style="overflow:hidden;">
								<div>
									<xsl:choose>
										<xsl:when test="$datatype = 'user'">
											<xsl:attribute name="class">entraid-dashboard-image-medium-numbers-charts-users</xsl:attribute>
										</xsl:when>
										<xsl:when test="$datatype = 'group'">
											<xsl:attribute name="class">entraid-dashboard-image-medium-numbers-charts-groups</xsl:attribute>
										</xsl:when>
										<xsl:when test="$datatype = 'role'">
											<xsl:attribute name="class">entraid-dashboard-image-medium-numbers-charts-roles</xsl:attribute>
										</xsl:when>
										<xsl:when test="$datatype = 'license'">
											<xsl:attribute name="class">entraid-dashboard-image-medium-numbers-charts-licenses</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="class">entraid-dashboard-image-medium-numbers-charts-users</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
								</div>
								<div class="entraid-dashboard-text-medium-numbers-charts">
									<xsl:choose>
										<xsl:when test="$datatype = 'user'">
											<xsl:value-of select="$entraid_config_modus_text_users" />
										</xsl:when>
										<xsl:when test="$datatype = 'group'">
											<xsl:value-of select="$entraid_config_modus_text_groups" />
										</xsl:when>
										<xsl:when test="$datatype = 'role'">
											<xsl:value-of select="$entraid_config_modus_text_roles" />
										</xsl:when>
										<xsl:when test="$datatype = 'license'">
											<xsl:value-of select="$entraid_config_modus_text_licenses" />
										</xsl:when>
										<xsl:otherwise>
											EntraID
										</xsl:otherwise>
									</xsl:choose>
								</div>
							</div>
						</div>
					</xsl:when>
					
					
					<xsl:when test="$mode='big_all' or not($mode)">
						<div class="daccord-dashboard-edit-box">	
							<div class="daccord-dashboard-edit-box-buttons">
								<inchorus-button>
									<xsl:attribute name="id"><xsl:value-of select="$parentid" />-edit-button-config</xsl:attribute>
									<xsl:attribute name="type">icon</xsl:attribute>
									<xsl:attribute name="icon">config</xsl:attribute>
									<xsl:attribute name="title"><xsl:value-of select="$entraid_config_button_customize" /></xsl:attribute>
									<xsl:attribute name="onclick">
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/>').setParameters(
											{
												"mode":"<xsl:value-of select="$mode" />",
												"configurationmode":"<xsl:value-of select="$configurationmode"/>",
												"contentcontainerid":"<xsl:value-of select="$contentcontainerid"/>",
												"contentvariationid":"<xsl:value-of select="$contentvariationid"/>"
											}
										);
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/>').activate();
										inchorus.$('<xsl:value-of select="$parentid"/>-edit-lightbox-config-<xsl:value-of select="$contentvariationid"/>').activate();									
									</xsl:attribute>
									<xsl:attribute name="highlighting">medium</xsl:attribute>
									<xsl:attribute name="class">dac-dashboard-edit-button-config</xsl:attribute>
								</inchorus-button>
								
								<inchorus-button>
									<xsl:attribute name="id"><xsl:value-of select="$parentid" />-delete-button-delete</xsl:attribute>
									<xsl:attribute name="type">icon</xsl:attribute>
									<xsl:attribute name="icon">delete</xsl:attribute>
									<xsl:attribute name="title"><xsl:value-of select="$entraid_config_button_remove" /></xsl:attribute>
									<xsl:attribute name="onclick">
										inchorus.$('<xsl:value-of select="$parentid"/>-delete-lightbox-config-<xsl:value-of select="$contentvariationid"/>').activate();									
									</xsl:attribute>
									<xsl:attribute name="highlighting">medium</xsl:attribute>
									<xsl:attribute name="class">dac-dashboard-edit-button-delete</xsl:attribute>
								</inchorus-button>
							</div>
							<div style="overflow:hidden;">
								<div class="entraid-dashboard-image-big-all">
								</div>
								<div class="entraid-dashboard-text-big-all">
									<xsl:value-of select="$entraid_config_modus_text_fullscore" />
								</div>
							</div>
						</div>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
<!-- 			
			<xsl:when test="$mode='hidden'">
			
				<xsl:if test="$configurationmode = 'edit'">

					<inchorus-button>
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-edit-button-config</xsl:attribute>
						<xsl:attribute name="type">icon</xsl:attribute>
						<xsl:attribute name="icon">config</xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="$entraid_config_button_customize" /></xsl:attribute>
						<xsl:attribute name="onclick">
							inchorus.$('<xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/>').activate();
							inchorus.$('<xsl:value-of select="$parentid"/>-edit-lightbox-config-<xsl:value-of select="$contentvariationid"/>').activate();									
						</xsl:attribute>
						<xsl:attribute name="highlighting">low</xsl:attribute>
					</inchorus-button>
					
					<inchorus-button>
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-delete-button-delete</xsl:attribute>
						<xsl:attribute name="type">icon</xsl:attribute>
						<xsl:attribute name="icon">delete</xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="$entraid_config_button_remove" /></xsl:attribute>
						<xsl:attribute name="onclick">
							inchorus.$('<xsl:value-of select="$parentid"/>-delete-lightbox-config-<xsl:value-of select="$contentvariationid"/>').activate();									
						</xsl:attribute>
						<xsl:attribute name="highlighting">low</xsl:attribute>
					</inchorus-button>
					
				</xsl:if>
			
			</xsl:when>
-->						
			<xsl:otherwise>
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.entraid.css" />

				<div>						
					<xsl:choose>
						<xsl:when test="$mode='small_numbers'">
							<xsl:attribute name="class">daccord-dashboard-box entraid-mode-small-numbers</xsl:attribute>	
							<xsl:choose>
								<xsl:when test="$datatype = 'user'">
									<inchorus-content>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-users-overview</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="alternativecontentfile"><xsl:value-of select="$parentid" />-users-overview-smallnumbers</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="command">getUserCountSummaryForDashboard</xsl:attribute>
									</inchorus-content>
							 	</xsl:when>
								<xsl:when test="$datatype = 'group'">
									<inchorus-content>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-groups-overview</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="alternativecontentfile"><xsl:value-of select="$parentid" />-groups-overview-smallnumbers</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="command">getGroupCountSummaryForDashboard</xsl:attribute>
									</inchorus-content>
								</xsl:when>
								<xsl:when test="$datatype = 'role'">
									<inchorus-content>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-roles-overview</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="alternativecontentfile"><xsl:value-of select="$parentid" />-roles-overview-smallnumbers</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="command">getRoleCountSummaryForDashboard</xsl:attribute>
									</inchorus-content>
							 	</xsl:when>
							 	<xsl:when test="$datatype = 'license'">
									<inchorus-content>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-licenses-overview</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="alternativecontentfile"><xsl:value-of select="$parentid" />-licenses-overview-smallnumbers</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="command">getLicenseCountSummaryForDashboard</xsl:attribute>
									</inchorus-content>
							 	</xsl:when>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="$mode='medium_numbers_charts'">
							<xsl:attribute name="class">daccord-dashboard-box entraid-mode-medium-numbers-charts</xsl:attribute>
							<h1>
								<xsl:value-of select="$entraid_dashboard_headline" />
							</h1>
 
							<div class="entraid-mode-medium-numbers-charts-policies-wrapper">
							 	<inchorus-content>
									<xsl:attribute name="id"><xsl:value-of select="$parentid" />-policies</xsl:attribute>
									<xsl:attribute name="hascontentfile">true</xsl:attribute>
									<xsl:attribute name="active">true</xsl:attribute>
									<xsl:attribute name="command">getPoliciesSummary</xsl:attribute>
								</inchorus-content>
							</div>

							<xsl:choose>
								<xsl:when test="$datatype = 'user'">
				 					<inchorus-content>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-users</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="parameters">[{"mode":"<xsl:value-of select="$mode" />"},{"charttypes":"<xsl:value-of select="$charttypes" />"}]</xsl:attribute>
									</inchorus-content>								
								</xsl:when>
								<xsl:when test="$datatype = 'group'">
									<inchorus-content>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-groups</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="parameters">[{"mode":"<xsl:value-of select="$mode" />"},{"charttypes":"<xsl:value-of select="$charttypes" />"}]</xsl:attribute>
									</inchorus-content>
								</xsl:when>
								<xsl:when test="$datatype = 'role'">
									<inchorus-content>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-roles</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="parameters">[{"mode":"<xsl:value-of select="$mode" />"},{"charttypes":"<xsl:value-of select="$charttypes" />"}]</xsl:attribute>
									</inchorus-content>
								</xsl:when>
								<xsl:when test="$datatype = 'license'">
									<inchorus-content>
										<xsl:attribute name="id"><xsl:value-of select="$parentid" />-licenses</xsl:attribute>
										<xsl:attribute name="hascontentfile">true</xsl:attribute>
										<xsl:attribute name="active">true</xsl:attribute>
										<xsl:attribute name="parameters">[{"mode":"<xsl:value-of select="$mode" />"},{"charttypes":"<xsl:value-of select="$charttypes" />"}]</xsl:attribute>
									</inchorus-content>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="$mode='big_all' or not($mode)">
							<xsl:attribute name="class">daccord-dashboard-box entraid-mode-big-all</xsl:attribute>
							<h1>
								<xsl:value-of select="$entraid_dashboard_headline" />
							</h1>

							<div class="entraid-mode-big-all-policies-wrapper">
							 	<inchorus-content>
									<xsl:attribute name="id"><xsl:value-of select="$parentid" />-policies</xsl:attribute>
									<xsl:attribute name="hascontentfile">true</xsl:attribute>
									<xsl:attribute name="active">true</xsl:attribute>
									<xsl:attribute name="command">getPoliciesSummary</xsl:attribute>
								</inchorus-content>
							</div>

		 					<inchorus-content>
								<xsl:attribute name="id"><xsl:value-of select="$parentid" />-users</xsl:attribute>
								<xsl:attribute name="hascontentfile">true</xsl:attribute>
								<xsl:attribute name="active">true</xsl:attribute>
								<xsl:attribute name="parameters">[{"mode":"<xsl:value-of select="$mode" />"},{"charttypes":"<xsl:value-of select="$charttypes" />"}]</xsl:attribute>
							</inchorus-content>
							<div style="height:48px;"></div>
		  					<inchorus-content>
								<xsl:attribute name="id"><xsl:value-of select="$parentid" />-groups</xsl:attribute>
								<xsl:attribute name="hascontentfile">true</xsl:attribute>
								<xsl:attribute name="active">true</xsl:attribute>
								<xsl:attribute name="parameters">[{"mode":"<xsl:value-of select="$mode" />"},{"charttypes":"<xsl:value-of select="$charttypes" />"}]</xsl:attribute>
							</inchorus-content>
						</xsl:when>
						<xsl:otherwise>
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</xsl:otherwise>		
		</xsl:choose>

		<xsl:if test="$configurationmode = 'edit'">
				<inchorus-lightbox>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-edit-lightbox-config-<xsl:value-of select="$contentvariationid"/></xsl:attribute>
					<xsl:attribute name="class">entraid-edit-lightbox-config</xsl:attribute>
					<xsl:attribute name="active">false</xsl:attribute>
	
					<h3><xsl:value-of select="$entraid_config_headline_gadgetconfiguration" /></h3>
					<div class="inchorus-lightbox-options">
			      
						<!-- lightbox close button start -->
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-close</xsl:attribute>
							<xsl:attribute name="type">icon</xsl:attribute>
							<xsl:attribute name="icon">close</xsl:attribute>
							<xsl:attribute name="border">false</xsl:attribute>
							<xsl:attribute name="highlighting">none</xsl:attribute>
							<xsl:attribute name="hover">false</xsl:attribute>
							<xsl:attribute name="active">true</xsl:attribute>
							<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_close" /></xsl:attribute>
							<xsl:attribute name="onclick">
								inchorus.$('<xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/>').deactivate();
								inchorus.$('<xsl:value-of select="$parentid"/>-edit-lightbox-config-<xsl:value-of select="$contentvariationid"/>').deactivate();
							</xsl:attribute>
						</inchorus-button>
						<!-- lightbox close button end -->
			
					</div>
					
					<div class="entraid-edit-lightbox-config-content-scrollable">
						<inchorus-content>
							<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-edit-config-<xsl:value-of select="$contentvariationid"/></xsl:attribute>
							<xsl:attribute name="active">false</xsl:attribute>
							<xsl:attribute name="hascontentfile">true</xsl:attribute>
							<xsl:attribute name="alternativecontentfile">configuration-modify</xsl:attribute>
			 				<xsl:attribute name="parameters">[{"configurationmode":"<xsl:value-of select="$configurationmode"/>"},{"contentcontainerid":"<xsl:value-of select="$contentcontainerid"/>"},{"contentvariationid":"<xsl:value-of select="$contentvariationid"/>"}]</xsl:attribute>
						</inchorus-content>
					</div>
	
				</inchorus-lightbox>
				
				<inchorus-lightbox>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-delete-lightbox-config-<xsl:value-of select="$contentvariationid"/></xsl:attribute>
					<xsl:attribute name="class">entraid-config-lightbox-delete</xsl:attribute>
					<xsl:attribute name="active">false</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">configuration-remove</xsl:attribute>
	 				<xsl:attribute name="parameters">[{"configurationmode":"<xsl:value-of select="$configurationmode"/>"},{"contentcontainerid":"<xsl:value-of select="$contentcontainerid"/>"},{"contentvariationid":"<xsl:value-of select="$contentvariationid"/>"}]</xsl:attribute>
				</inchorus-lightbox>			
			</xsl:if>
			
	</xsl:template>
</xsl:stylesheet>