<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">entraid-admin-policies-policydetails-history</xsl:variable>
		<xsl:variable name="policyid" select="//parameters/parameter[@name='policyid']" />
		<xsl:variable name="qualitylevel" select="//parameters/parameter[@name='qualitylevel']" />
		<xsl:variable name="duration" select="//parameters/parameter[@name='duration']" />
		<xsl:variable name="description" select="//data/policy/description" />
		<xsl:variable name="objectname" select="//data/policy/objectname" />
		<xsl:variable name="status" select="//data/policy/status" />
		<xsl:variable name="level_low_comparevalue1" select="//data/policy/level_low_comparevalue1" />
		<xsl:variable name="level_low_comparevalue2" select="//data/policy/level_low_comparevalue2" />
		<xsl:variable name="level_medium_comparevalue1" select="//data/policy/level_medium_comparevalue1" />
		<xsl:variable name="level_medium_comparevalue2" select="//data/policy/level_medium_comparevalue2" />
		<xsl:variable name="level_high_comparevalue1" select="//data/policy/level_high_comparevalue1" />
		<xsl:variable name="level_high_comparevalue2" select="//data/policy/level_high_comparevalue2" />
		<xsl:variable name="dates" select="//data/statistics/dates" />
		<xsl:variable name="values" select="//data/statistics/values" />
		
		<xsl:if test="$status != 'scheduled'">
		
			<inchorus-message>
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-message-notscheduled</xsl:attribute>
				<xsl:attribute name="type">warning</xsl:attribute>
				<xsl:value-of select="$entraid_message_policies_notscheduled" />
			</inchorus-message>
		
		</xsl:if>

		<div class="row dac-entraid-margintop-20px">
			<div class="dac-policies-policiesdetails-history-chart-wrapper">
				<div id="chart" class="dac-policies-policiesdetails-history-chart">
				</div>
				<div class="dac-policies-policiesdetails-history-chart-legend">
					
					<xsl:if test="$level_low_comparevalue1 &gt; '0' or $level_low_comparevalue2 &gt; '0'">
						<div class="dac-policies-policiesdetails-history-chart-legend-low-quader">
						</div>
						<div class="dac-policies-policiesdetails-history-chart-legend-low-text">
							<xsl:value-of select="$entraid_select_policies_legend_low_1"/>&#160;<xsl:value-of select="$level_low_comparevalue1" />&#160;<xsl:value-of select="$entraid_select_policies_legend_low_2"/>&#160;<xsl:value-of select="$level_low_comparevalue2" /><xsl:value-of select="$entraid_select_policies_legend_low_3"/>
						</div>
					</xsl:if>
					
					<xsl:if test="$level_medium_comparevalue1 &gt; '0' or $level_medium_comparevalue2 &gt; '0'">
						<div class="dac-policies-policiesdetails-history-chart-legend-medium-quader">
						</div>
						<div class="dac-policies-policiesdetails-history-chart-legend-medium-text">
							<xsl:value-of select="$entraid_select_policies_legend_medium_1"/>&#160;<xsl:value-of select="$level_medium_comparevalue1" />&#160;<xsl:value-of select="$entraid_select_policies_legend_medium_2"/>&#160;<xsl:value-of select="$level_medium_comparevalue2" /><xsl:value-of select="$entraid_select_policies_legend_medium_3"/>
						</div>
					</xsl:if>
					
					<xsl:if test="$level_high_comparevalue1 &gt; '0' or $level_high_comparevalue2 &gt; '0'">
						<div class="dac-policies-policiesdetails-history-chart-legend-high-quader">
						</div>
						<div class="dac-policies-policiesdetails-history-chart-legend-high-text">
							<xsl:value-of select="$entraid_select_policies_legend_high_1"/>&#160;<xsl:value-of select="$level_high_comparevalue1" />&#160;<xsl:value-of select="$entraid_select_policies_legend_high_2"/>&#160;<xsl:value-of select="$level_high_comparevalue2" /><xsl:value-of select="$entraid_select_policies_legend_high_3"/>
						</div>
					</xsl:if>
					
					<div class="dac-policies-policiesdetails-history-chart-legend-data-circle">
					</div>
					<div class="dac-policies-policiesdetails-history-chart-legend-data-text">
						<xsl:value-of select="$entraid_select_policies_legend_numberof" /><xsl:value-of select="$objectname" />
					</div>
				</div>
			</div>
		</div>
		
		<script>
			var options = {
				annotations: {
			        yaxis: [{
			          y: <xsl:value-of select="$level_low_comparevalue1" />,
			          y2: <xsl:value-of select="$level_low_comparevalue2" />,
			          borderColor: '#000',
			          fillColor: '#4f8e56',
			          opacity: 0.2,
			          label: {
			            borderColor: 'transparent',
			            style: {
			              fontSize: '0px',
			              color: 'transparent',
			              background: 'transparent',
			              display: 'none',
			            },
			            text: '.'
			          }
			        },
			        {
			          y: <xsl:value-of select="$$level_low_comparevalue2" />,
			          y2: <xsl:value-of select="$level_medium_comparevalue2" />,
			          borderColor: '#000',
			          fillColor: '#FFBA00',
			          opacity: 0.2,
			          label: {
			            borderColor: 'transparent',
			            style: {
			              fontSize: '0px',
			              color: 'transparent',
			              background: 'transparent',
			            },
			            text: '.',
			          }
			        },
			        {
			          y: <xsl:value-of select="$level_medium_comparevalue2" />,
			          y2: <xsl:value-of select="$level_high_comparevalue2" />,
			          borderColor: '#000',
			          fillColor: '#ef1e1e',
			          opacity: 0.2,
			          label: {
			            borderColor: 'transparent',
			            style: {
			              fontSize: '0px',
			              color: 'transparent',
			              background: 'transparent',
			            },
			            text: '.',
			          }
			        }],
			        xaxis: [{
			          x: new Date('23 Nov 2017').getTime(),
			          strokeDashArray: 0,
			          borderColor: '#775DD0',
			          label: {
			            borderColor: '#775DD0',
			            style: {
			              color: '#fff',
			              background: '#775DD0',
			            },
			            text: 'Anno Test',
			          }
			        }, {
			          x: new Date('26 Nov 2017').getTime(),
			          x2: new Date('28 Nov 2017').getTime(),
			          fillColor: '#B3F7CA',
			          opacity: 0.4,
			          label: {
			            borderColor: '#B3F7CA',
			            style: {
			              fontSize: '10px',
			              color: '#fff',
			              background: '#00E396',
			            },
			            offsetY: -10,
			            text: 'X-axis range',
			          }
			        }],
			        points: [{
			          x: new Date('01 Dec 2017').getTime(),
			          y: 8607.55,
			          marker: {
			            size: 8,
			            fillColor: '#fff',
			            strokeColor: 'red',
			            radius: 2,
			            cssClass: 'apexcharts-custom-class'
			          },
			          label: {
			            borderColor: '#FF4560',
			            offsetY: 0,
			            style: {
			              color: '#fff',
			              background: '#FF4560',
			            },
			
			            text: 'Point Annotation',
			          }
			        }]
			      },           
			            chart: {
			                height: 250,
			                type: 'line',
			                zoom: {
			                    enabled: false
			                }
			            },
			            series: [{
			                name: "<xsl:value-of select="$objectname" />",
			                data: [<xsl:value-of select="$values" />]
			            }],
			            dataLabels: {
			                enabled: false
			            },
			            stroke: {
			                curve: 'straight'
			            },
			            title: {
			                text: '<xsl:value-of select="$description" />',
			                align: 'left'
			            },
			            grid: {
			                row: {
			                    colors: ['#f3f3f3', 'transparent'], // takes an array which will be repeated on columns
			                    opacity: 0.5
			                },
			            },
			            xaxis: {
			                categories: [<xsl:value-of select="$dates" />],
			            }
			        }
			
			        var chart = new ApexCharts(
			            document.querySelector("#chart"),
			            options
			 );
			
			 chart.render();
		</script>

	</xsl:template>
</xsl:stylesheet>