<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">entraid-admin-quickfilter</xsl:variable>
		<xsl:variable name="previousparentid">entraid-admin</xsl:variable>
		<xsl:variable name="countusers" select="//data/countusers" />
		<xsl:variable name="countgroups" select="//data/countgroups" />
		<xsl:variable name="countroles" select="//data/countroles" />
		<xsl:variable name="countlicenseplans" select="//data/countlicenseplans" />
		<xsl:variable name="counttenant" select="count(//data/systems/system)" />
		<xsl:variable name="tenantname" select="//data/systems/system/name" />
		<xsl:variable name="tenantname_length" select="string-length($tenantname)" />
		<xsl:variable name="tenantid" select="//data/systems/system/systemid" />
		<xsl:variable name="active" select="//parameters/parameter[@name='active']" />
		<!-- <xsl:variable name="qf" select="//parameters/parameter[@name='qf']" /> -->
		<xsl:variable name="view" select="//parameters/parameter[@name='view']" />
		<xsl:variable name="systemid" select="//parameters/parameter[@name='systemid']" />
		<xsl:variable name="systemname" select="//parameters/parameter[@name='systemname']" />
		<xsl:variable name="systemname_length" select="string-length($systemname)" />

		<div class="entraid-admin-quickfilter-row">
		
			<script>
				inchorus.$('<xsl:value-of select="$previousparentid" />-users').setParameters(
					{
						"systemid":"<xsl:value-of select="$systemid" />"
					}
				);
				inchorus.$('<xsl:value-of select="$previousparentid" />-groups').setParameters(
					{
						"systemid":"<xsl:value-of select="$systemid" />"
					}
				);
				inchorus.$('<xsl:value-of select="$previousparentid" />-roles').setParameters(
					{
						"systemid":"<xsl:value-of select="$systemid" />"
					}
				);
				inchorus.$('<xsl:value-of select="$previousparentid" />-licenses').setParameters(
					{
						"systemid":"<xsl:value-of select="$systemid" />"
					}
				);			
			</script>
			
			
			<div id="entraid-admin-quickfilter-selecttenant" class="entraid-admin-quickfilter-row-box entraid-admin-quickfilter-entraid">
					<xsl:attribute name="onClick">
							inchorus.$('<xsl:value-of select="$parentid" />-tooltip-selecttenant').setPosition('bottom-center');
							inchorus.$('<xsl:value-of select="$parentid" />-tooltip-selecttenant').setLinkedpointerid('<xsl:value-of select="$parentid" />-selecttenant');
							inchorus.$('<xsl:value-of select="$parentid" />-tooltip-selecttenant').activate();
					</xsl:attribute>
				<div class="dashboard-statistic color-green entraid-admin-quickfilter-row-box-wrapper" style="cursor: default;" >
					<div class="entraid-admin-quickfilter-row-box-content">
						<div class="entraid-admin-quickfilter-headline">
							<h3>
								<xsl:attribute name="id"><xsl:value-of select="$parentid" />-entraid-h3</xsl:attribute>
								<xsl:choose>
									<xsl:when test="$counttenant = '1'">
										<xsl:choose>
											<xsl:when test="$tenantname_length &gt; '9' and $tenantname_length &lt; '12'">
												<xsl:attribute name="class"><xsl:value-of select="$parentid" />-headline-fontsize-35pt</xsl:attribute>
											</xsl:when>
											<xsl:when test="$tenantname_length &gt; '11' and $tenantname_length &lt; '14'">
												<xsl:attribute name="class"><xsl:value-of select="$parentid" />-headline-fontsize-30pt</xsl:attribute>
											</xsl:when>
											<xsl:when test="$tenantname_length &gt; '13' and $tenantname_length &lt; '16'">
												<xsl:attribute name="class"><xsl:value-of select="$parentid" />-headline-fontsize-25pt</xsl:attribute>
											</xsl:when>
											<xsl:when test="$tenantname_length &gt; '15'">
												<xsl:attribute name="class"><xsl:value-of select="$parentid" />-headline-fontsize-20pt</xsl:attribute>
											</xsl:when>
										</xsl:choose>
									
										<xsl:choose>
											<xsl:when test="$tenantname_length &gt; '18'">
												<xsl:call-template name="shorten">
													<xsl:with-param name="string" select="$tenantname"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<nobr><xsl:value-of select="$tenantname"/></nobr>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:when test="$systemid != ''">
										<xsl:choose>
											<xsl:when test="$systemname_length &gt; '9' and $systemname_length &lt; '12'">
												<xsl:attribute name="class"><xsl:value-of select="$parentid" />-headline-fontsize-35pt</xsl:attribute>
											</xsl:when>
											<xsl:when test="$systemname_length &gt; '11' and $systemname_length &lt; '14'">
												<xsl:attribute name="class"><xsl:value-of select="$parentid" />-headline-fontsize-30pt</xsl:attribute>
											</xsl:when>
											<xsl:when test="$systemname_length &gt; '13' and $systemname_length &lt; '16'">
												<xsl:attribute name="class"><xsl:value-of select="$parentid" />-headline-fontsize-25pt</xsl:attribute>
											</xsl:when>
											<xsl:when test="$systemname_length &gt; '15'">
												<xsl:attribute name="class"><xsl:value-of select="$parentid" />-headline-fontsize-20pt</xsl:attribute>
											</xsl:when>
										</xsl:choose>
										<xsl:choose>
											<xsl:when test="$systemname_length &gt; '18'">
												<xsl:call-template name="shorten">
													<xsl:with-param name="string" select="$systemname"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<nobr><xsl:value-of select="$systemname"/></nobr>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$counttenant"/>
									</xsl:otherwise>
								</xsl:choose>
							</h3>
						</div>
						<xsl:if test="$counttenant != '1'">
							<div class="entraid-admin-quickfilter-text">
								<span class="entraid-admin-quickfilter-green">
									<xsl:choose>
										<xsl:when test="$counttenant != '1' and $systemid = ''">
											<xsl:value-of select="$entraid_admin_quickfilter_tenant_1" /><br/><xsl:value-of select="$entraid_admin_quickfilter_tenant_2" />
										</xsl:when>
										<xsl:otherwise>
											
										</xsl:otherwise>
									</xsl:choose> 
								</span>
							</div>
						</xsl:if>
					</div>
				</div>
			</div>
			<div class="entraid-admin-quickfilter-row-box">
 				<xsl:attribute name="onClick">
					inchorus.$('<xsl:value-of select="$previousparentid" />-quickfilter').setParameters(
						{
							"systemid":"<xsl:value-of select="$systemid" />",
							"systemname":"<xsl:value-of select="$systemname" />",
							"active":"users"
						}
					);
					inchorus.$('<xsl:value-of select="$previousparentid" />-quickfilter').load();
					inchorus.$('<xsl:value-of select="$previousparentid" />-users').activate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-groups').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-roles').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-licenses').deactivate();
				</xsl:attribute>
				<div class="dashboard-statistic color-green entraid-admin-quickfilter-row-box-wrapper">
					<xsl:attribute name="title">
						<xsl:value-of select="$countusers" />&#160;<xsl:value-of select="$entraid_admin_quickfilter_user_1" />&#160;<xsl:value-of select="$entraid_admin_quickfilter_user_2" />
					</xsl:attribute>
					<div>
						<xsl:choose>
							<xsl:when test="not($active) and not($view)">
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-users-active</xsl:attribute>
							</xsl:when>
							<xsl:when test="$active = 'users' or $view = '' or $view = 'user-list' or $view = 'user-history-list'">
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-users-active</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-users</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<div class="entraid-admin-quickfilter-headline">
							<h3>
								<xsl:call-template name="format-longnumber">
									<xsl:with-param name="number" select="$countusers"/>
								</xsl:call-template>
							</h3>
						</div>
						<div class="entraid-admin-quickfilter-text">
							<span class="entraid-admin-quickfilter-green">
								<xsl:value-of select="$entraid_admin_quickfilter_user_1" /><br/><xsl:value-of select="$entraid_admin_quickfilter_user_2" />
							</span>
						</div>
					</div>
				</div>
			</div>
			<div class="entraid-admin-quickfilter-row-box">
				<xsl:attribute name="onClick">
					inchorus.$('<xsl:value-of select="$previousparentid" />-quickfilter').setParameters(
						{
							"systemid":"<xsl:value-of select="$systemid" />",
							"systemname":"<xsl:value-of select="$systemname" />",
							"active":"groups"
						}
					);
					inchorus.$('<xsl:value-of select="$previousparentid" />-quickfilter').load();
					inchorus.$('<xsl:value-of select="$previousparentid" />-users').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-roles').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-licenses').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-groups').activate();
				</xsl:attribute>
				<div class="dashboard-statistic color-red entraid-admin-quickfilter-row-box-wrapper">
					<xsl:attribute name="title">
						<xsl:value-of select="$countgroups" />&#160;<xsl:value-of select="$entraid_admin_quickfilter_groups_1" />&#160;<xsl:value-of select="$entraid_admin_quickfilter_groups_2" />
					</xsl:attribute>
					<div>
						<xsl:choose>
							<xsl:when test="$active = 'groups' or $view = 'group-list' or $view = 'group-history-list'">
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-groups-active</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-groups</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<div class="entraid-admin-quickfilter-headline">
							<h3>
								<xsl:call-template name="format-longnumber">
									<xsl:with-param name="number" select="$countgroups"/>
								</xsl:call-template>
							</h3>
						</div>
						<div class="entraid-admin-quickfilter-text">
							<span class="entraid-admin-quickfilter-red">
								<xsl:value-of select="$entraid_admin_quickfilter_groups_1" /><br/><xsl:value-of select="$entraid_admin_quickfilter_groups_2" />
							</span>
						</div>
					</div>
				</div>
			</div>
			<div class="entraid-admin-quickfilter-row-box">
 				<xsl:attribute name="onClick">
					inchorus.$('<xsl:value-of select="$previousparentid" />-quickfilter').setParameters(
						{
							"systemid":"<xsl:value-of select="$systemid" />",
							"systemname":"<xsl:value-of select="$systemname" />",
							"active":"roles"
						}
					);
					inchorus.$('<xsl:value-of select="$previousparentid" />-quickfilter').load();
					inchorus.$('<xsl:value-of select="$previousparentid" />-users').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-groups').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-licenses').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-roles').activate();
				</xsl:attribute>
				<div class="dashboard-statistic color-green entraid-admin-quickfilter-row-box-wrapper">
					<xsl:attribute name="title">
						<xsl:value-of select="$countroles" />&#160;<xsl:value-of select="$entraid_admin_quickfilter_roles_1" />&#160;<xsl:value-of select="$entraid_admin_quickfilter_roles_2" />
					</xsl:attribute>
					<div>
						<xsl:choose>
							<xsl:when test="not($active) and not($view)">
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-roles-active</xsl:attribute>
							</xsl:when>
							<xsl:when test="$active = 'roles' or $view = 'roles-list' or $view = 'roles-history-list'">
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-roles-active</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-roles</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<div class="entraid-admin-quickfilter-headline">
							<h3>
								<xsl:call-template name="format-longnumber">
									<xsl:with-param name="number" select="$countroles"/>
								</xsl:call-template>
							</h3>
						</div>
						<div class="entraid-admin-quickfilter-text">
							<span class="entraid-admin-quickfilter-green">
								<xsl:value-of select="$entraid_admin_quickfilter_roles_1" /><br/><xsl:value-of select="$entraid_admin_quickfilter_roles_2" />
							</span>
						</div>
					</div>
				</div>
			</div>
			<div class="entraid-admin-quickfilter-row-box">
 				<xsl:attribute name="onClick">
					inchorus.$('<xsl:value-of select="$previousparentid" />-quickfilter').setParameters(
						{
							"systemid":"<xsl:value-of select="$systemid" />",
							"systemname":"<xsl:value-of select="$systemname" />",
							"active":"licenses"
						}
					);
					inchorus.$('<xsl:value-of select="$previousparentid" />-quickfilter').load();
					inchorus.$('<xsl:value-of select="$previousparentid" />-users').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-groups').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-roles').deactivate();
					inchorus.$('<xsl:value-of select="$previousparentid" />-licenses').activate();
				</xsl:attribute>
				<div class="dashboard-statistic color-green entraid-admin-quickfilter-row-box-wrapper">
					<xsl:attribute name="title">
						<xsl:value-of select="$countlicenseplans" />&#160;<xsl:value-of select="$entraid_admin_quickfilter_licenses_1" />&#160;<xsl:value-of select="$entraid_admin_quickfilter_licenses_2" />
					</xsl:attribute>
					<div>
						<xsl:choose>
							<xsl:when test="not($active) and not($view)">
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-licenses-active</xsl:attribute>
							</xsl:when>
							<xsl:when test="$active = 'licenses' or $view = 'licenses-list' or $view = 'licenses-history-list'">
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-licenses-active</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class">entraid-admin-quickfilter-row-box-content entraid-admin-quickfilter-licenses</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<div class="entraid-admin-quickfilter-headline">
							<h3>
								<xsl:call-template name="format-longnumber">
									<xsl:with-param name="number" select="$countlicenseplans"/>
								</xsl:call-template>
							</h3>
						</div>
						<div class="entraid-admin-quickfilter-text">
							<span class="entraid-admin-quickfilter-green">
								<xsl:value-of select="$entraid_admin_quickfilter_licenses_1" /><br/><xsl:value-of select="$entraid_admin_quickfilter_licenses_2" />
							</span>
						</div>
					</div>
				</div>
			</div>
		</div>
		
		<inchorus-tooltip>
			<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tooltip-selecttenant</xsl:attribute>
			<xsl:attribute name="position">bottom-center</xsl:attribute>
			<xsl:attribute name="active">false</xsl:attribute>
			<xsl:attribute name="closeonoutsideclick">true</xsl:attribute>
			<xsl:attribute name="hascontentfile">false</xsl:attribute>
			<xsl:attribute name="linkedpointerid"><xsl:value-of select="$parentid" />-selecttenant</xsl:attribute>
			<xsl:attribute name="linkedpointertype">arrow</xsl:attribute>
			<xsl:attribute name="deactivationcontentmode">remove</xsl:attribute>
			<xsl:attribute name="class">dac-tooltip-reports</xsl:attribute>
			<xsl:attribute name="style">margin-top:-20px;width: 300px;</xsl:attribute>
			
			<div class="entraid-tooltip-wrapper" style="padding: 15px 0px 20px 0px !important;">
				<xsl:value-of select="$entraid_tooltip_text_entraid" />
				<br/><br/>
				<b><xsl:value-of select="$entraid_tooltip_label_entraid" /></b>
					
				<inchorus-select>
					<xsl:attribute name="id"><xsl:value-of select="$parentid" />-field-selecttenant</xsl:attribute>
					<xsl:attribute name="name">inc-ftSystemid</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">select-tenant</xsl:attribute>
					<xsl:attribute name="command">getAllEntraIDTenants</xsl:attribute>
					<xsl:attribute name="preselect"><xsl:value-of select="$systemid" /></xsl:attribute>
					<xsl:attribute name="active">true</xsl:attribute>

					<xsl:attribute name="onchange">
						if(jQuery('#entraid-admin-users-filter').attr('active') == 'true') {
							jQuery('#entraid-admin-users-filter-field-systemid').val(jQuery('#entraid-selectTenant').val());
							inchorus.$('entraid-admin-users-filter').submit();
							inchorus.$('entraid-admin-quickfilter-tooltip-selecttenant').deactivate();
							
							systemid = jQuery('#entraid-admin-users-filter-field-systemid').val();
							systemname = $("#entraid-selectTenant option:selected").text();
							
							jQuery('#entraid-selectTenant-table').val(systemid);
							
							inchorus.$('<xsl:value-of select="$parentid" />').setParameters(
								{
									"systemid":systemid,
									"systemname":systemname,
									"active":"users"
								}
							);
							inchorus.$('<xsl:value-of select="$parentid" />').load();

						} else if (jQuery('#entraid-admin-groups-filter').attr('active') == 'true'){
							jQuery('#entraid-admin-groups-filter-field-systemid').val(jQuery('#entraid-selectTenant').val());
							inchorus.$('entraid-admin-groups-filter').submit();
							inchorus.$('entraid-admin-quickfilter-tooltip-selecttenant').deactivate();

							systemid = jQuery('#entraid-admin-groups-filter-field-systemid').val();
							systemname = $("#entraid-selectTenant option:selected").text();
							
							jQuery('#entraid-selectTenant-table').val(systemid);
							
							inchorus.$('<xsl:value-of select="$parentid" />').setParameters(
								{
									"systemid":systemid,
									"systemname":systemname,
									"active":"groups"
								}
							);
							inchorus.$('<xsl:value-of select="$parentid" />').load();
							
						} else if (jQuery('#entraid-admin-roles-filter').attr('active') == 'true'){
							jQuery('#entraid-admin-roles-filter-field-systemid').val(jQuery('#entraid-selectTenant').val());
							inchorus.$('entraid-admin-roles-filter').submit();
							inchorus.$('entraid-admin-quickfilter-tooltip-selecttenant').deactivate();

							systemid = jQuery('#entraid-admin-roles-filter-field-systemid').val();
							systemname = $("#entraid-selectTenant option:selected").text();
							
							jQuery('#entraid-selectTenant-table').val(systemid);
							
							inchorus.$('<xsl:value-of select="$parentid" />').setParameters(
								{
									"systemid":systemid,
									"systemname":systemname,
									"active":"roles"
								}
							);
							inchorus.$('<xsl:value-of select="$parentid" />').load();
							
						} else if (jQuery('#entraid-admin-licenses-filter').attr('active') == 'true'){
							jQuery('#entraid-admin-licenses-filter-field-systemid').val(jQuery('#entraid-selectTenant').val());
							inchorus.$('entraid-admin-licenses-filter').submit();
							inchorus.$('entraid-admin-quickfilter-tooltip-selecttenant').deactivate();

							systemid = jQuery('#entraid-admin-licenses-filter-field-systemid').val();
							systemname = $("#entraid-selectTenant option:selected").text();
							
							jQuery('#entraid-selectTenant-table').val(systemid);
							
							inchorus.$('<xsl:value-of select="$parentid" />').setParameters(
								{
									"systemid":systemid,
									"systemname":systemname,
									"active":"licenses"
								}
							);
							inchorus.$('<xsl:value-of select="$parentid" />').load();
						}
					</xsl:attribute>
				</inchorus-select>
			</div>
		</inchorus-tooltip>
	</xsl:template>
	
	<xsl:template name="shorten">
  		<xsl:param name="string" />
		<xsl:choose>
	 		<xsl:when test="string-length($string) > 18">
				<xsl:value-of select="concat(substring($string, 1, 18), '...')"/>
	 		</xsl:when>
	 		<xsl:otherwise>
				<xsl:value-of select="$string"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="format-longnumber">
	    <xsl:param name="number"/>
	    <xsl:choose>
	      <xsl:when test="$number &lt; '10000'">
	        	<xsl:value-of select="$number"/>
	      </xsl:when>
	      <xsl:when test="$number &lt; '100000'">
	        	<xsl:value-of select="substring($number,1,2)"/>.<xsl:value-of select="substring($number,3,1)"/>k
	      </xsl:when>
	      <xsl:when test="$number = '100000'">
	        	<xsl:value-of select="substring($number,1,2)"/>k
	      </xsl:when>
	      <xsl:when test="$number &lt; '1000000'">
	        	<xsl:value-of select="substring($number,1,3)"/>.<xsl:value-of select="substring($number,4,1)"/>k
	      </xsl:when>
	      <xsl:when test="$number &lt; '1100000'">
	        	1M
	      </xsl:when>
	      <xsl:when test="$number &lt; '10000000'">
	        	<xsl:value-of select="substring($number,1,1)"/>.<xsl:value-of select="substring($number,2,1)"/>M
	      </xsl:when>
	      <xsl:when test="$number &lt; '100000000'">
	        	<xsl:value-of select="substring($number,1,2)"/>.<xsl:value-of select="substring($number,3,1)"/>M
	      </xsl:when>
	      <xsl:when test="$number &lt; '1000000000'">
	        	<xsl:value-of select="substring($number,1,3)"/>M
	      </xsl:when>
	      <xsl:when test="$number &gt;= '1000000000'">
	        	<xsl:value-of select="$number"/>
	      </xsl:when>
	      <xsl:otherwise>
	        	<xsl:value-of select="$number"/>
	      </xsl:otherwise>
	    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>