<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_setup.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="inchorus-form-validity" select="//data/parameters/parameter[@name='inchorus-form-validity']"/>
		<xsl:variable name="connecteddomain" select="//data/parameters/parameter[@name='connecteddomain']"/>
		<xsl:variable name="authority" select="connection/authority"/>
		<xsl:variable name="tenant" select="connection/tenant"/>
		<xsl:variable name="clientid" select="connection/clientid"/>
		<xsl:variable name="secret" select="connection/secret"/>
		<xsl:variable name="scope" select="connection/scope"/>
		<xsl:variable name="tenantname" select="connection/tenantname"/>
		<xsl:variable name="result" select="connection/result"/>
		<xsl:variable name="statuscode" select="//data/status/code" />
		
		<xsl:variable name="proxyhost" select="connection/proxyhost" />
		<xsl:variable name="proxyport" select="connection/proxyport" />
		<xsl:variable name="sslproxy" select="connection/sslproxy" />
		<xsl:variable name="proxyusername" select="connection/proxyusername" />
		<xsl:variable name="proxypassword" select="connection/proxypassword" />
		
		<!-- 
		<xsl:variable name="statustype" select="//data/status/type" />	
		<xsl:variable name="statuscode" select="//data/status/code" />	
		<xsl:variable name="contentid" select="//session/contentid" />
		<xsl:variable name="connected" select="//data/connection/connected" />
		<xsl:variable name="message" select="//data/connection/message" />
		<xsl:variable name="domainname" select="//data/connection/domainname" />
		<xsl:variable name="domainbasedn" select="//data/connection/domainbasedn" />
		<xsl:variable name="host" select="//data/connection/host" />
		<xsl:variable name="hostname" select="//data/connection/hostname" />
		<xsl:variable name="ssl" select="//data/connection/ssl" />
		<xsl:variable name="port" select="//data/connection/port" />	
		<xsl:variable name="userdn" select="//data/connection/userdn" />
		<xsl:variable name="userpw" select="//data/connection/userpw" />
		-->
		
		<script>
			inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem-button-check').setStatus('enabled');
		</script>
				
		<xsl:choose>
			<xsl:when test="$inchorus-form-validity='false'">
				<inchorus-message id="config-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_message_error_validation" />
				</inchorus-message>				
			</xsl:when>
			<xsl:when test="$result = 'ERROR'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_error_ldaphost" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$statuscode = 'ERROR_SYSTEM_EXISTS'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_error_systemexists" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$result = 'SUCCESS'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">success</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_success" />
				</inchorus-message>
				<script>
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem-button-check').deactivate();
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem-button-abort').deactivate();
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem-button-next').activate();
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem').setAlternativecontentfile('entraid-portalsetup-admin-systems-lightbox-addsystem-add');
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem').setParameters(
							{
								"connected":"true",
								"authority":"<xsl:value-of select="$authority"/>",
								"tenant":"<xsl:value-of select="$tenant"/>",
								"clientid":"<xsl:value-of select="$clientid"/>",
								"secret":"<xsl:value-of select="$secret"/>",
								"scope":"<xsl:value-of select="$scope"/>",
								"tenantname":"<xsl:value-of select="$tenantname"/>",
								"result":"<xsl:value-of select="$result"/>",
								"connecteddomain":"<xsl:value-of select="$connecteddomain"/>",
								"proxyhost":"<xsl:value-of select="$proxyhost"/>",
								"proxyport":"<xsl:value-of select="$proxyport"/>",
								"sslproxy":"<xsl:value-of select="$sslproxy"/>",
								"proxyusername":"<xsl:value-of select="$proxyusername"/>",
								"proxypassword":"<xsl:value-of select="$proxypassword"/>"
							}
					);
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem').load();
					jQuery('#system-admin-systems-lightbox').removeClass('addsystem_EntraIDTenant_step2');
					jQuery('#system-admin-systems-lightbox').addClass('addsystem_EntraIDTenant_step3');
				</script>
			</xsl:when>
			
			<!-- 
			<xsl:when test="$message = 'ERROR_INVALID_CREDENTIALS'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_error_credentials" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$message = 'ERROR_UNKNOWN_HOST'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_error_unknownhost" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$message = 'ERROR_HOST_UNREACHABLE'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_error_host" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$message = 'ERROR_LDAP_CONNECTION'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_error_ldaphost" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$message = 'ERROR_RETRIEVE_HOSTNAME'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_error_hostname" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$connected = 'false'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">error</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_error_host" />
				</inchorus-message>
			</xsl:when>
			<xsl:when test="$connected = 'true'">
				<inchorus-message id="setup-portal-createportaldb-form-error">
					<xsl:attribute name="type">success</xsl:attribute>
					<xsl:value-of select="$entraid_setup_system_lightbox_message_success" />
				</inchorus-message>
				<script>
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem-button-check').deactivate();
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem-button-abort').deactivate();
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem-button-next').activate();
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem').setAlternativecontentfile('entraid-portalsetup-admin-systems-lightbox-addsystem-add');
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem').setParameters(
							{
								"connected":"<xsl:value-of select="$connected"/>",
								"message": "<xsl:value-of select="$message"/>",
								"domainname":"<xsl:value-of select="$domainname"/>",
								"domainbasedn":"<xsl:value-of select="$domainbasedn"/>",
								"host":"<xsl:value-of select="$host"/>",
								"hostname":"<xsl:value-of select="$hostname"/>",
								"ssl":"<xsl:value-of select="$ssl"/>",
								"port":"<xsl:value-of select="$port"/>",
								"userdn":"<xsl:value-of select="$userdn"/>",
								"userpw":"<xsl:value-of select="$userpw"/>"
							}
					);
					inchorus.$('entraid-portalsetup-admin-systems-lightbox-addsystem').load();
					jQuery('#system-admin-systems-lightbox').removeClass('addsystem_EntraIDDomain_step2');
					jQuery('#system-admin-systems-lightbox').addClass('addsystem_EntraIDDomain_step3');
				</script>
			</xsl:when>
			-->
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>