<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_setup.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">entraid-systemsetup-connector-localconnectors</xsl:variable>
		<xsl:variable name="initmajorstate" select="initmajorstate"/>
		<xsl:variable name="initminorstate" select="initminorstate"/>
		<xsl:variable name="initmessage" select="initmessage"/>
		<xsl:variable name="position" select="//data/connector/position" />
		<xsl:variable name="exists" select="//data/connector/exists" />
		<xsl:variable name="status" select="//data/connector/status" />
		<xsl:variable name="url" select="//data/connector/url" />
		<xsl:variable name="statusmessage" select="//data/connector/statusmessage" />
		<xsl:variable name="statuscode" select="//data/status/code" />
		<xsl:variable name="platform" select="//data/connector/platform" />
		<xsl:variable name="version" select="//data/connector/version" />
		
		<xsl:variable name="installmode" select="//data/installmode" />

		<xsl:choose>						 
			<xsl:when test="not(//data/connector) or $statuscode = 'ERROR_CONNECTOR_NOTLOCAL'">
					<div>			
						<div>
							<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
						</div>
	
						<div class="dac-system-box-error">
							<div class="dac-system-box-error-wrapper">
								<h2><xsl:value-of select="$entraid_setup_adconnector" /></h2>
								<p><b><xsl:value-of select="$entraid_setup_text_noadconnector" /></b></p>
							</div>
						</div>
					</div>
					<!-- 
					<div style="border: 1px dashed #888;height:173px;margin-bottom:40px;width: 270px;float:right;cursor: pointer;">
						<div style="text-align: center;margin-top:75px;">+ Remote hinzuf&#252;gen</div>
					</div>
					-->
				
			</xsl:when>
			<xsl:when test="($statusmessage = 'ERROR_CONNECTOR_NOTCONFIGURED' or $statusmessage = 'ERROR_CONNECTOR_NODB' or $statusmessage = 'ERROR_DB_QUERY') and $exists = 'false'">
				<div>
					<div>
						<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
					</div>

					<div style="float:left;border: 1px solid #ddd;overflow:hidden;height:auto;background-color:#fff;border-radius: 6px;width: 268px;">
						<xsl:choose>
							<xsl:when test="$statusmessage = 'ERROR_CONNECTOR_NOTCONFIGURED'">
								<xsl:attribute name="class">dac-system-border-grey</xsl:attribute>
							</xsl:when>	
							<xsl:otherwise>
								<xsl:attribute name="class">dac-system-border-red</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<div style="padding:0px 15px; 15px 20px;">
							<h2 style="margin-bottom:10px;">
								<div class="dac-system-entraid-icon"></div>
								<xsl:value-of select="$entraid_setup_adconnector" />
							</h2>
							<p style="color:#ddd;font-weight:bold;">
								<xsl:if test="$statusmessage != 'ERROR_CONNECTOR_NOTCONFIGURED'">
									<xsl:attribute name="class">dac-system-red</xsl:attribute>
								</xsl:if>
								
								<xsl:choose>
									<xsl:when test="$statusmessage = 'ERROR_CONNECTOR_NODB'">
										<xsl:value-of select="$entraid_setup_statusmessage_error_connector_nodb" />
									</xsl:when>
									<xsl:when test="$statusmessage = 'ERROR_CONNECTOR_NOTCONFIGURED'">
										<xsl:value-of select="$entraid_setup_statusmessage_error_connector_notconfigured" />
									</xsl:when>
									<xsl:when test="$statusmessage = 'ERROR_DB_QUERY'">
										<xsl:value-of select="$entraid_setup_statusmessage_error_db_query" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$statusmessage" />
									</xsl:otherwise>
								</xsl:choose>
							</p>
							<div style="margin-bottom:20px;line-height:24px;">
								<xsl:choose>
									<xsl:when test="$statusmessage = 'ERROR_CONNECTOR_NOTCONFIGURED'">
										<p><xsl:value-of select="$entraid_setup_statusmessage_error_connector_notconfigured_text" /></p>
										<xsl:choose>
											<xsl:when test="string-length($version) = 3">
												<xsl:value-of select="$entraid_setup_version" />&#160;<xsl:value-of select="substring($version,1,1)"/>.<xsl:value-of select="substring($version,2,1)"/>.<xsl:value-of select="substring($version,3,1)"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="$entraid_setup_version" />&#160;<xsl:value-of select="$version"/>
											</xsl:otherwise>
										</xsl:choose> 
										<br/>
										<xsl:value-of select="$entraid_setup_platform" />:&#160;<span style="text-transform:uppercase;"><xsl:value-of select="$platform" /></span>
									</xsl:when>
									<xsl:when test="$statusmessage = 'ERROR_DB_QUERY'">
										<xsl:value-of select="$entraid_setup_statusmessage_error_db_query_text"/>
									</xsl:when>
									<xsl:when test="$statusmessage = 'ERROR_CONNECTOR_NODB'">
										<xsl:value-of select="$entraid_setup_statusmessage_error_connector_nodb_text"/>
									</xsl:when>
								</xsl:choose>
							</div>
						</div>
						<xsl:if test="$statusmessage = 'ERROR_CONNECTOR_NOTCONFIGURED'">
							<div style="border-top: 1px solid #ddd;padding:10px;">
								<xsl:choose>	
									<xsl:when test="$statusmessage = 'ERROR_CONNECTOR_NOTCONFIGURED'">
										<xsl:choose>
											<xsl:when test="$installmode='advanced' or $platform='windows'">
												<inchorus-button style="margin-bottom:10px;float:right;margin-right:0px;background-color: #fff;">
													<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-add</xsl:attribute>
													<xsl:attribute name="type">icontext</xsl:attribute>
													<xsl:attribute name="icon">new</xsl:attribute>
													<xsl:attribute name="text"><xsl:value-of select="$entraid_setup_button_add" /></xsl:attribute>
													<xsl:attribute name="onclick">
														inchorus.$('entraid-systemsetup-connector-lightbox').setParameters(
															{
																"url":"<xsl:value-of select="$url" />",
																"platform":"<xsl:value-of select="$platform" />"
															}
														);
														inchorus.$('entraid-systemsetup-connector-lightbox').activate();
													</xsl:attribute>
												</inchorus-button>
											</xsl:when>
											<xsl:otherwise>
												<inchorus-button style="margin-bottom:10px;float:right;margin-right:0px;background-color: #fff;">
													<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-add</xsl:attribute>
													<xsl:attribute name="type">icontext</xsl:attribute>
													<xsl:attribute name="icon">new</xsl:attribute>
													<xsl:attribute name="text"><xsl:value-of select="$entraid_setup_button_add" /></xsl:attribute>
													<xsl:attribute name="status">enabled</xsl:attribute>
													<xsl:attribute name="onclick">
														inchorus.$('<xsl:value-of select="$parentid"/>-button-add').setStatus('loading');
														inchorus.$('<xsl:value-of select="$parentid"/>-form').setCommand('importEntraIDConnectorSimple');
														inchorus.$('<xsl:value-of select="$parentid"/>-form').submit();
													</xsl:attribute>
												</inchorus-button>						
											</xsl:otherwise>
										</xsl:choose>
									
									</xsl:when>
									<xsl:otherwise>
										<div style="height:34px; width:34px;"></div>
									</xsl:otherwise>
								</xsl:choose>
							</div>
						</xsl:if>
					</div>
				</div>
				<!--  
				<div style="border: 1px dashed #888;height:173px;margin-bottom:40px;width: 270px;float:right;cursor: pointer;">
					<div style="text-align: center;margin-top:75px;">+ Remote hinzuf&#252;gen</div>
				</div>
				-->
			</xsl:when>
			<xsl:otherwise>
				<div style="border: 1px dashed #888;height:173px;margin-bottom:40px;width: 100%;float:right;">
					<div style="text-align: center;margin-top:75px;">
						<xsl:value-of select="$entraid_setup_nootherentraidconnector" />
					</div>
				</div>
			</xsl:otherwise>
		</xsl:choose>
		
		<inchorus-form>
			<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-form</xsl:attribute>
			<xsl:attribute name="submitprefix">inc-</xsl:attribute>
			<xsl:attribute name="alternativeresponsefile"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
			<xsl:attribute name="responsetargetid"><xsl:value-of select="$parentid"/>-response</xsl:attribute>
			<xsl:attribute name="hasresponsefile">true</xsl:attribute>
			<input type="hidden" name="inc-url">
				<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-form-url</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$url" /></xsl:attribute>				
			</input>
		</inchorus-form>
	
		<script>
			entraid.setup.divelement();
		</script>
	</xsl:template>
</xsl:stylesheet>