<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_setup.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">entraid-systemsetup-system-addedsystems-systemdetails</xsl:variable>
		<xsl:variable name="lastnodecounttotal" select="//data/systems/collectorstatistic/lastnodecounttotal" />
		<xsl:variable name="collectorstatistic_count" select="//data/systems/collectorstatistic/count" />
		<xsl:variable name="collectorstatistic_count_scheduled" select="//data/systems/collectorstatistic/count_scheduled" />
		<xsl:variable name="collectorstatistic_count_running" select="//data/systems/collectorstatistic/count_running" />
		<xsl:variable name="collectorstatistic_count_error" select="//data/systems/collectorstatistic/count_error" />
		<xsl:variable name="systemid" select="parameters/parameter[@name='systemid']" />
		<xsl:variable name="processpercentage" select="//data/systems/collectorstatistic/processpercentage" />
		<xsl:variable name="lastruntime" select="//data/systems/collectorstatistic/lastruntime" />
		<xsl:variable name="laststarttime" select="//data/systems/collectorstatistic/laststarttime" />
		<xsl:variable name="nextstarttime" select="//data/systems/collectorstatistic/nextstarttime" />
		<xsl:variable name="lastruntime_days" select="//data/systems/collectorstatistic/lastruntime_days" />
		<xsl:variable name="lastruntime_hours" select="//data/systems/collectorstatistic/lastruntime_hours" />
		<xsl:variable name="lastruntime_minutes" select="//data/systems/collectorstatistic/lastruntime_minutes" />
		<xsl:variable name="lastruntime_seconds" select="//data/systems/collectorstatistic/lastruntime_seconds" />
	
		<div style="margin-bottom: 10px;font-weight:bold;"><xsl:value-of select="$entraid_setup_numberofobjects" />&#160;<xsl:value-of select="$lastnodecounttotal" /></div>
		
		<xsl:if test="$collectorstatistic_count_error != '0'">
			<b class="textcolor_red">ERROR</b>
			<div style="color:#de536f;margin-bottom:8px;">
				<xsl:value-of select="$entraid_setup_error_collector" />
			</div>
		</xsl:if>
		
		<div class="progress">
			<xsl:choose>
				<xsl:when test="$collectorstatistic_count_error = '0' and $collectorstatistic_count_running = '0' and $laststarttime != ''">
					<xsl:attribute name="title">100%</xsl:attribute>
				</xsl:when>
				<xsl:when test="$collectorstatistic_count_error != '0'">
					<xsl:attribute name="title">ERROR</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="title"><xsl:value-of select="$processpercentage" />%</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			
			<div class="progress-bar">
				<xsl:choose>
					<xsl:when test="$collectorstatistic_count_running &gt; '0'">
						<xsl:attribute name="class">progress-bar dac-system-progress-warning</xsl:attribute>
						<xsl:attribute name="style">width:<xsl:value-of select="$processpercentage" />%;</xsl:attribute>
						<script>
							$("#entraid-systemsetup-system-addedsystems-tooltip-entraid-<xsl:value-of select="$systemid" /> .dac-system-tooltip-wrapper .dac-system-tooltip-options-row").hide();
							$("#entraid-systemsetup-system-addedsystems-tooltip-entraid-<xsl:value-of select="$systemid" /> .dac-system-tooltip-wrapper .dac-system-tooltip-options-row-last").hide();
							inchorus.$("entraid-systemsetup-system-addedsystems-message-nomenubecauserunning-<xsl:value-of select="$systemid"/>").activate();
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-success');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-notread');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-error');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").addClass('dac-system-box-warning');
						
							setTimeout(function(){
								inchorus.$('entraid-systemsetup-system-addedsystems-box-content-<xsl:value-of select="$systemid" />').load();
							}, 3000);
						</script>
					</xsl:when>	
					<xsl:when test="$collectorstatistic_count_error &gt; '0'">
						<xsl:attribute name="class">progress-bar dac-system-progress-error</xsl:attribute>
						<xsl:attribute name="style">width:<xsl:value-of select="$processpercentage" />%;</xsl:attribute>
						<script>
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-success');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-notread');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-warning');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").addClass('dac-system-box-error');
							$("#entraid-systemsetup-system-addedsystems-tooltip-entraid-<xsl:value-of select="$systemid" /> .dac-system-tooltip-wrapper .dac-system-tooltip-options-row").show();
							$("#entraid-systemsetup-system-addedsystems-tooltip-entraid-<xsl:value-of select="$systemid" /> .dac-system-tooltip-wrapper .dac-system-tooltip-options-row-last").show();
							inchorus.$("entraid-systemsetup-system-addedsystems-message-nomenubecauserunning-<xsl:value-of select="$systemid"/>").deactivate();
							
						</script>
					</xsl:when>
					<xsl:when test="$collectorstatistic_count_error = '0' and $collectorstatistic_count_running = '0' and $laststarttime != ''">
						<xsl:attribute name="class">progress-bar dac-system-progress-success</xsl:attribute>
						<xsl:attribute name="style">width:100%;</xsl:attribute>
						<script>
							$("#entraid-systemsetup-system-addedsystems-tooltip-entraid-<xsl:value-of select="$systemid" /> .dac-system-tooltip-wrapper .dac-system-tooltip-options-row").show();
							$("#entraid-systemsetup-system-addedsystems-tooltip-entraid-<xsl:value-of select="$systemid" /> .dac-system-tooltip-wrapper .dac-system-tooltip-options-row-last").show();
							inchorus.$("entraid-systemsetup-system-addedsystems-message-nomenubecauserunning-<xsl:value-of select="$systemid"/>").deactivate();
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-warning');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-notread');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-error');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").addClass('dac-system-box-success');
						</script>
					</xsl:when>
					<xsl:otherwise>
						<script>
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-warning');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-success');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").removeClass('dac-system-box-error');
							$("#entraid-systemsetup-system-addedsystems-system-<xsl:value-of select="$systemid" /> div.dac-system-box").addClass('dac-system-box-notread');
						</script>
					</xsl:otherwise>
				</xsl:choose>
			</div>
		</div>
		
		<xsl:if test="$laststarttime != 'null' and $laststarttime !=''">
				<xsl:value-of select="$entraid_setup_runtime" />:<br/>
				<xsl:choose>
					<xsl:when test="$lastruntime_days &gt; '0'">
						<xsl:value-of select="$lastruntime_days" />&#160;<xsl:value-of select="$entraid_setup_days" />&#160;<xsl:value-of select="$lastruntime_hours" />&#160;<xsl:value-of select="$entraid_setup_hours" />&#160;<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$entraid_setup_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$entraid_setup_seconds" /><br/>
					</xsl:when>
					<xsl:when test="$lastruntime_hours &gt; '0'">
						<xsl:value-of select="$lastruntime_hours" />&#160;<xsl:value-of select="$entraid_setup_hours" />&#160;<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$entraid_setup_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$entraid_setup_seconds" /><br/>
					</xsl:when>
					<xsl:when test="$lastruntime_minutes &gt; '0'">
						<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$entraid_setup_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$entraid_setup_seconds" /><br/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$entraid_setup_seconds" /><br/>
					</xsl:otherwise>
				</xsl:choose>
				<div style="margin-top:5px;">
					<xsl:value-of select="$entraid_setup_box_lastcollect_start" /><br/>
					<xsl:choose>
						<xsl:when test="'<!--GADGET:LANGUAGE-->' = 'de'">
							<xsl:value-of select="substring($laststarttime,9,2)"/>.<xsl:value-of select="substring($laststarttime,6,2)"/>.<xsl:value-of select="substring($laststarttime,1,4)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="substring($laststarttime,1,4)"/>-<xsl:value-of select="substring($laststarttime,6,2)"/>-<xsl:value-of select="substring($laststarttime,9,2)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
						</xsl:otherwise>
					</xsl:choose>
				</div>
		</xsl:if>
		
		<xsl:if test="$nextstarttime != 'null' and $nextstarttime !=''">
			<div style="margin-top:5px;">
				<xsl:value-of select="$entraid_setup_box_nextcollect" /><br/>
				<xsl:choose>
					<xsl:when test="'<!--GADGET:LANGUAGE-->' = 'de'">
						<xsl:value-of select="substring($nextstarttime,9,2)"/>.<xsl:value-of select="substring($nextstarttime,6,2)"/>.<xsl:value-of select="substring($nextstarttime,1,4)"/>&#160;<xsl:value-of select="substring($nextstarttime,12,8)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="substring($nextstarttime,1,4)"/>-<xsl:value-of select="substring($nextstarttime,6,2)"/>-<xsl:value-of select="substring($nextstarttime,9,2)"/>&#160;<xsl:value-of select="substring($nextstarttime,12,8)"/>
					</xsl:otherwise>
				</xsl:choose>
			</div>
		</xsl:if>

		<script>
			setTimeout(function(){
				entraid.setup.divelement();
			}, 200);
		</script>
		
	</xsl:template>
</xsl:stylesheet>