<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">index</xsl:variable>
		<xsl:variable name="tab" select="//parameters/parameter[@name='tab']" />
		<xsl:variable name="qf" select="//parameters/parameter[@name='qf']" />
		<xsl:variable name="view" select="//parameters/parameter[@name='view']" />
		<xsl:variable name="systemid" select="//parameters/parameter[@name='systemid']" />
		<xsl:variable name="systemtype" select="//parameters/parameter[@name='systemtype']" />
		<xsl:variable name="systemname" select="//parameters/parameter[@name='systemname']" />
		<xsl:variable name="spid" select="//parameters/parameter[@name='spid']" />
		<xsl:variable name="rsid" select="//parameters/parameter[@name='rsid']" />
		<xsl:variable name="details" select="//parameters/parameter[@name='details']" />
		
		<xsl:variable name="modus" select="//data/parameters/parameter[@name='modus']/text()"/>
		<xsl:variable name="header" select="//parameters/parameter[@name='header']" />
		<xsl:variable name="hasheader" select="//parameters/parameter[@name='hasheader']" />
		<xsl:variable name="uniqueid" select="//parameters/parameter[@name='uniqueid']" />
		<xsl:variable name="function_to_close" select="//parameters/parameter[@name='function_to_close']" />
		
		<xsl:variable name="openedslider" select="//parameters/parameter[@name='openedslider']" />
		<xsl:variable name="integrationpackageid" select="//parameters/parameter[@name='integrationpackageid']" />
		<xsl:variable name="integrationpackagestatus" select="//parameters/parameter[@name='integrationpackagestatus']" />
		<xsl:variable name="path" select="//parameters/parameter[@name='path']" />
			
		<xsl:if test="$modus='setup'">
			<script type="text/javascript" src="/<!--GADGET:PATH-->/inc/js/inchorus.{$gadgetname}.setup.js" />
		</xsl:if>
		
		<!-- Gadget specific CSS -->
		<xsl:choose>
			<xsl:when test="$modus = 'hidden'">
			</xsl:when>
			<xsl:when test="$modus='setup' or $modus='portalsetupaddentraid' or $modus='portalsetupeditentraid'">
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.{$gadgetname}.setup.css" />
			</xsl:when>
			<xsl:otherwise>
				<script type="text/javascript" src="/<!--GADGET:PATH-->/inc/js/inchorus.{$gadgetname}.js" />
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.{$gadgetname}.css" />
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:choose>	
			<xsl:when test="$modus='setup'">
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.entraid.setup.css" />
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-systemsetup</xsl:attribute>
			  		<xsl:attribute name="hascontentfile">true</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">entraid-systemsetup</xsl:attribute>
			  		<xsl:attribute name="command">checkComponents</xsl:attribute>
				</inchorus-content>
			</xsl:when>
			
			<xsl:when test="$modus='portalsetupadd'">
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.entraid.setup.css" />
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-portalsetup-admin-systems-lightbox-addsystem</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">entraid-portalsetup-admin-systems-lightbox-addsystem</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="command">getDefaultData</xsl:attribute>
				</inchorus-content>
			</xsl:when>
			
			<xsl:when test="$modus='portalsetupedit'">
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.entraid.setup.css" />
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-portalsetup-admin-systems-lightbox-editsystem</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">entraid-portalsetup-admin-systems-lightbox-editsystem</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
					<xsl:attribute name="parameters">[{"systemid":"<xsl:value-of select="$systemid" />"},{"systemtype":"<xsl:value-of select="$systemtype" />"},{"header":"<xsl:value-of select="$header" />"}]</xsl:attribute>
			  		<xsl:attribute name="command">getDefaultData</xsl:attribute>
				</inchorus-content>
			</xsl:when>
			
			<xsl:when test="$modus='systemdetails'">
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-portalsetup-admin-system-slider-systemdetails</xsl:attribute>
					<xsl:attribute name="active">true</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-systemdetails</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="parameters">[{"systemid":"<xsl:value-of select="$systemid" />"},{"systemtype":"<xsl:value-of select="$systemtype" />"},{"systemname":"<xsl:value-of select="$systemname"/>"},{"path":"<xsl:value-of select="$path" />"},{"header":"<xsl:value-of select="$header" />"},{"function_to_close":"<xsl:value-of select="$function_to_close" />"}]</xsl:attribute>
			  		<xsl:attribute name="command">checkRequiredComponentStatus</xsl:attribute>
			  		<div class="entraid-slider-akkordeon-loader" style="margin-top:calc(75% - 24px);">
						<xsl:value-of select="$loader_pleasewait" />
					</div>
				</inchorus-content>
			</xsl:when>	
			
			<xsl:when test="$modus='entraiduser'">
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/inchorus.entraid.css" />
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-details-content</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-admin-entraiduser-details</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="command">getDefaultData</xsl:attribute>
			  		<xsl:attribute name="parameters">[{"modus":"<xsl:value-of select="$modus" />"},{"uniqueid":"<xsl:value-of select="$uniqueid" />"},{"systemid":"<xsl:value-of select="$systemid" />"},{"hasheader":"<xsl:value-of select="$hasheader" />"},{"header":"<xsl:value-of select="$header" />"},{"function_to_close":"<xsl:value-of select="$function_to_close" />"}]</xsl:attribute>
				</inchorus-content>
				
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-details-secondary</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-details-content</xsl:attribute>
			  		<xsl:attribute name="hascontentfile">true</xsl:attribute> 			
		 			<xsl:attribute name="active">false</xsl:attribute>
			  		<xsl:attribute name="animation">fade</xsl:attribute>
			  		<xsl:attribute name="animationspeed">500</xsl:attribute>
			  		<xsl:attribute name="style">display:none;</xsl:attribute>
			  		<xsl:attribute name="class">dac-slider-right</xsl:attribute>
				</inchorus-content>
			</xsl:when>
			
			<xsl:when test="$modus='entraiduser-history'">
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-details-content-history</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-admin-entraiduser-details-history-list-details</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="command">getHistoryDetailsById</xsl:attribute>
			  		<xsl:attribute name="parameters">[{"modus":"<xsl:value-of select="$modus" />"},{"id":"<xsl:value-of select="$uniqueid" />"},{"systemid":"<xsl:value-of select="$systemid" />"},{"hasheader":"<xsl:value-of select="$hasheader" />"},{"header":"<xsl:value-of select="$header" />"},{"function_to_close":"<xsl:value-of select="$function_to_close" />"}]</xsl:attribute>
				</inchorus-content>
			</xsl:when>
			
			<xsl:when test="$modus='entraidrole'">
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-details-content</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-admin-entraidrole-details</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="command">getDefaultData</xsl:attribute>
			  		<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid" />"},{"systemid":"<xsl:value-of select="$systemid" />"},{"header":"<xsl:value-of select="$header" />"},{"function_to_close":"<xsl:value-of select="$function_to_close" />"}]</xsl:attribute>
				</inchorus-content>
			</xsl:when>
			
			<xsl:when test="$modus='entraidlicense'">
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-details-content</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-admin-entraidlicense-details</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="command">getDefaultData</xsl:attribute>
			  		<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid" />"},{"systemid":"<xsl:value-of select="$systemid" />"},{"header":"<xsl:value-of select="$header" />"},{"function_to_close":"<xsl:value-of select="$function_to_close" />"}]</xsl:attribute>
				</inchorus-content>
			</xsl:when>
			
			<xsl:when  test="$modus='effectiveview_securityprincipals'">

				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-details-content</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-admin-linkedresource-entraiduser-details</xsl:attribute>
					<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="command">getDefaultData</xsl:attribute>
			  		<xsl:attribute name="parameters">[{"modus":"effectiveview_securityprincipals"},{"uniqueid":"<xsl:value-of select="$uniqueid" />"},{"systemid":"<xsl:value-of select="$systemid" />"},{"hasheader":"true"},{"header":"<xsl:value-of select="$header" />"},{"integrationpackageid":"<xsl:value-of select="$integrationpackageid" />"},{"openedslider":"<xsl:value-of select="$openedslider"/>"},{"function_to_close":"<xsl:value-of select="$function_to_close" />"}]</xsl:attribute>
				</inchorus-content>
				
			</xsl:when>
			
			<xsl:otherwise>
		
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-details</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-details-content</xsl:attribute>
			  		<xsl:attribute name="hascontentfile">true</xsl:attribute> 			
		 			<xsl:attribute name="active">false</xsl:attribute>
			  		<xsl:attribute name="animation">fade</xsl:attribute>
			  		<xsl:attribute name="animationspeed">500</xsl:attribute>
			  		<xsl:attribute name="style">display:none;</xsl:attribute>
				</inchorus-content>
		
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-details-secondary</xsl:attribute>
					<xsl:attribute name="alternativecontentfile">slider-details-content</xsl:attribute>
			  		<xsl:attribute name="hascontentfile">true</xsl:attribute> 			
		 			<xsl:attribute name="active">false</xsl:attribute>
			  		<xsl:attribute name="animation">fade</xsl:attribute>
			  		<xsl:attribute name="animationspeed">500</xsl:attribute>
			  		<xsl:attribute name="style">display:none;</xsl:attribute>
			  		<xsl:attribute name="class">dac-slider-right</xsl:attribute>
				</inchorus-content>
				
				<h1 class="dac-entraid-headline">
					<xsl:value-of select="$entraid_header" />
				</h1>
				
				<inchorus-tabs>
					<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tabs</xsl:attribute>
				   	<xsl:choose>
						<xsl:when test="$tab = 'admin'">
							<xsl:attribute name="activeheaderid"><xsl:value-of select="$parentid" />-tab-header-admin</xsl:attribute>
					    </xsl:when>
					    <xsl:when test="$tab = 'responsible'">
					   		<xsl:attribute name="activeheaderid"><xsl:value-of select="$parentid" />-tab-header-responsible</xsl:attribute>
					    </xsl:when>
					    <xsl:otherwise>
						   	<xsl:attribute name="activeheaderid"><xsl:value-of select="$parentid" />-tab-header-admin</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
		
				   	<inchorus-tab-header-area>
				   		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tab-header-area</xsl:attribute>
				    		
				     	<inchorus-tab-header>
				     		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tab-header-admin</xsl:attribute>
				        	<xsl:attribute name="linkedcontentid"><xsl:value-of select="$parentid" />-tab-content-admin</xsl:attribute>
				        	<xsl:value-of select="$entraid_tab_administrator" />
				      	</inchorus-tab-header>
				      	
				    </inchorus-tab-header-area>
				    
					<inchorus-tab-content-area>
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tabs-content-area</xsl:attribute>
					    <inchorus-tab-content>
					    	<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tab-content-admin</xsl:attribute>
					       	<xsl:attribute name="hascontentfile">true</xsl:attribute>
					      	<xsl:attribute name="alternativecontentfile">entraid-admin</xsl:attribute>
					      	<xsl:attribute name="command">getAllEntraIDTenants</xsl:attribute>
					      	<xsl:attribute name="parameters">[{"view":"<xsl:value-of select="$view"/>"},{"qf":"<xsl:value-of select="$qf"/>"},{"systemid":"<xsl:value-of select="$systemid"/>"}]</xsl:attribute>
					    </inchorus-tab-content>
					    
					</inchorus-tab-content-area>
				</inchorus-tabs>
		
				<div>
					<xsl:attribute name="id">entraid-slider-maximized-notclickable</xsl:attribute>
					<xsl:attribute name="onClick">
						entraid.slider.hideDetailsMaximized();
						entraid.slider.hideDetails();
					</xsl:attribute>
				</div>				
			
				<inchorus-content>
			  		<xsl:attribute name="id">entraid-slider-maximized</xsl:attribute>
			  		<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="alternativecontentfile">entraid-admin-policies-policydetails</xsl:attribute>
			  		<xsl:attribute name="active">false</xsl:attribute>
			  		<xsl:attribute name="animation">fade</xsl:attribute>
			  		<xsl:attribute name="animationspeed">500</xsl:attribute>
			  		<xsl:attribute name="command">getPolicyDetails</xsl:attribute>
				</inchorus-content>

				<script type="text/javascript" src="/<!--GADGET:PATH-->/inc/js/jqui/jquery.ui.js" />
				<script type="text/javascript" src="/<!--GADGET:PATH-->/inc/js/jqui/<!--GADGET:LANGUAGE-->/datepicker_lang.js" />
				<link media="screen" rel="stylesheet" type="text/css" href="/<!--GADGET:PATH-->/inc/css/jqui/jquery.ui.css" />
				
				<link rel="stylesheet" type="text/css" href="inc/css/apexcharts/apexcharts.css" />
				<script type="text/javascript" src="inc/js/apexcharts/apexcharts.js" />	
			</xsl:otherwise>
				
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>