<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_history.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">slider-admin-entraidlicense-details-license</xsl:variable>
		<xsl:variable name="systemid" select="//parameters/parameter[@name='systemid']" />
		<xsl:variable name="name" select="//data/licenseplans/licenseplan/name" />
		<xsl:variable name="appliesTo" select="//data/licenseplans/licenseplan/appliesTo" />
		<xsl:variable name="capabilityStatus" select="//data/licenseplans/licenseplan/capabilityStatus" />
		<xsl:variable name="consumedUnits" select="//data/licenseplans/licenseplan/consumedUnits" />
		<xsl:variable name="skuId" select="//data/licenseplans/licenseplan/skuId" />
		<xsl:variable name="uniqueid" select="//data/licenseplans/licenseplan/uniqueid" />

		<div class="dac-slider-list">
			<div>
				<label>
					<xsl:value-of select="$entraid_label_objectsid"/>
				</label>
				<div>
					<xsl:value-of select="$uniqueid" />
				</div>
			</div>
			<div>
				<label>
					<xsl:value-of select="$entraid_label_appliesTo"/>
				</label>
				<div>
					<xsl:value-of select="$appliesTo" />
				</div>
			</div>
			<div>
				<label>
					<xsl:value-of select="$entraid_label_capabilityStatus"/>
				</label>
				<div>
					<xsl:choose>
						<xsl:when test="$capabilityStatus = 'Enabled'">
							<xsl:value-of select="$entraid_text_enabled" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$entraid_text_disabled" />
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</div>
			<div>
				<label>
					<xsl:value-of select="$entraid_label_consumedUnits"/>
				</label>
				<div>
					<xsl:value-of select="$consumedUnits" />
				</div>
			</div>
			<div>
				<label>
					<xsl:value-of select="$entraid_label_skuId"/>
				</label>
				<div>
					<xsl:value-of select="$skuId" />
				</div>
			</div>
		</div>
		
		<div class="dac-slider-scrollable-content" style="height: calc(100% - 375px);">
			<xsl.value-of select="$uniqueid" />
			<xsl.value-of select="$systemid" />

			<inchorus-akkordeon>
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-serviceplans-akkordeon</xsl:attribute>
				<xsl:attribute name="hascontentfile">true</xsl:attribute>
				<xsl:attribute name="type">first</xsl:attribute>
				<xsl:attribute name="alternativecontentfile"><xsl:value-of select="$parentid"/>-serviceplans</xsl:attribute>
				<xsl:attribute name="parameters">[{"uniqueidlicense":"<xsl:value-of select="$uniqueid"/>"}]</xsl:attribute>
				<xsl:attribute name="command">getEntraIDServicePlansForLicense</xsl:attribute>
				<xsl:attribute name="text"><xsl:value-of select="$entraid_label_serviceplans" /></xsl:attribute>
				<xsl:attribute name="onclick">entraid.slider.closeUnusedAkkordeons('<xsl:value-of select="$parentid" />-serviceplans-akkordeon');</xsl:attribute>
				<div class="entraid-slider-akkordeon-loader">
					<xsl:value-of select="$loader_pleasewait" />
				</div>
			</inchorus-akkordeon>
			
			<inchorus-akkordeon>
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-memberships-akkordeon</xsl:attribute>
				<xsl:attribute name="hascontentfile">true</xsl:attribute>
				<xsl:attribute name="type">first</xsl:attribute>
				<xsl:attribute name="alternativecontentfile"><xsl:value-of select="$parentid"/>-memberships</xsl:attribute>
				<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid"/>"},{"systemid":"<xsl:value-of select="$systemid"/>"}]</xsl:attribute>
				<xsl:attribute name="command">getLicenseMembers</xsl:attribute>
				<xsl:attribute name="text"><xsl:value-of select="$entraid_label_groupmemberships" /></xsl:attribute>
				<xsl:attribute name="onclick">entraid.slider.closeUnusedAkkordeons('<xsl:value-of select="$parentid" />-memberships-akkordeon');</xsl:attribute>
				<div class="entraid-slider-akkordeon-loader">
					<xsl:value-of select="$loader_pleasewait" />
				</div>
			</inchorus-akkordeon>
			
			<!-- 	
			<div class="dac-slider-list-small">
				<div class="dac-slider-list-small-header">
					<div>
						<b><xsl:value-of select="$entraid_label_groupmemberships"/></b>
					</div>
				</div>
										
				<div class="dac-slider-list-small-scrollable dac-slider-list-small-height-150px">
					<inchorus-content>
						<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-memberships</xsl:attribute>
						<xsl:attribute name="hascontentfile">true</xsl:attribute>
						<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid"/>"},{"systemid":"<xsl:value-of select="$systemid"/>"}]</xsl:attribute>
						<xsl:attribute name="command">getLicenseMembers</xsl:attribute>
					</inchorus-content>
				</div>
			</div>
			-->
		</div>
	</xsl:template>

</xsl:stylesheet>