<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="uniqueid" select="//parameters/parameter[@name='uniqueid']" />
		<xsl:variable name="systemid" select="//parameters/parameter[@name='systemid']" />
		<xsl:variable name="header" select="//parameters/parameter[@name='header']" />
		<xsl:variable name="hasheader" select="//parameters/parameter[@name='hasheader']" />
		<xsl:variable name="modus" select="//parameters/parameter[@name='modus']" />
		<xsl:variable name="function_to_close" select="//parameters/parameter[@name='function_to_close']" />
		<xsl:variable name="parentid">slider-admin-entraidlicense-details</xsl:variable>

		<xsl:variable name="hasPrint">false</xsl:variable>
		<xsl:variable name="hasExportcsv">true</xsl:variable>
		<xsl:variable name="hasExportpdf">true</xsl:variable>
		<xsl:variable name="mode">dev</xsl:variable>

		<xsl:if test="$hasheader != 'false'">
			<div class="dac-slider-border-top">
			</div>
		</xsl:if>
		
		<div>
			<xsl:if test="$hasheader != 'false'">
				<xsl:attribute name="class">dac-slider-content-wrapper</xsl:attribute>
			</xsl:if>
			
			<div class="dac-slider-content">
				<xsl:choose>
					<xsl:when test="$hasheader != 'false'">
						<xsl:attribute name="style">float:left;height: calc(100% - 8px);width:530px;</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="style">float:left;height: calc(100% - 8px);width:560px;</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			
			<xsl:if test="$hasheader != 'false'">
				<h1>
					<xsl:attribute name="title"><xsl:value-of select="$header"/></xsl:attribute>
					<xsl:attribute name="style">cursor:default;</xsl:attribute>
					<div class="entraid-slider-headline-icon entraid-slider-headline-icon-license"></div>
					<b>
						<xsl:choose>
						  <xsl:when test="string-length($header) > 30">
							<xsl:value-of select="concat(substring($header, 1, 27), '...')"/>
						  </xsl:when>
						  <xsl:otherwise>
							<xsl:value-of select="$header"/>
						  </xsl:otherwise>
						</xsl:choose>
					</b>
				</h1>
				
			
			<div class="dac-slider-right-options">
				<inchorus-button>
					<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-close</xsl:attribute>
					<xsl:attribute name="type">icon</xsl:attribute>
					<xsl:attribute name="icon">close</xsl:attribute>
					<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_close" /></xsl:attribute>
					<xsl:attribute name="highlighting">low</xsl:attribute>
					<xsl:attribute name="active">true</xsl:attribute>
					<xsl:attribute name="border">true</xsl:attribute>
					<xsl:attribute name="hover">true</xsl:attribute>
					<xsl:attribute name="onclick">
						<xsl:value-of select="$function_to_close" />
					</xsl:attribute>
				</inchorus-button>
			
				<xsl:if test="$hasExportcsv = 'true' or $hasExportpdf = 'true'">				
					<inchorus-button>
						<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-export</xsl:attribute>
						<xsl:attribute name="type">icon</xsl:attribute>
						<xsl:attribute name="icon">reports</xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_reports" /></xsl:attribute>
						<xsl:attribute name="highlighting">low</xsl:attribute>
						<xsl:attribute name="active">true</xsl:attribute>
						<xsl:attribute name="border">true</xsl:attribute>
						<xsl:attribute name="hover">true</xsl:attribute>
						<xsl:attribute name="style">float:right;margin-right:0px;</xsl:attribute>
						<xsl:attribute name="onclick">
							inchorus.$('<xsl:value-of select="$parentid" />-tooltip-export').activate();
						</xsl:attribute>
					</inchorus-button>
					<inchorus-tooltip>
						<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tooltip-export</xsl:attribute>
						<xsl:attribute name="position">bottom-left</xsl:attribute>
						<xsl:attribute name="active">false</xsl:attribute>
						<xsl:attribute name="closeonoutsideclick">true</xsl:attribute>
						<xsl:attribute name="hascontentfile">false</xsl:attribute>
						<xsl:attribute name="linkedpointerid"><xsl:value-of select="$parentid" />-button-export</xsl:attribute>
						<xsl:attribute name="linkedpointertype">arrow</xsl:attribute>
						<xsl:attribute name="deactivationcontentmode">remove</xsl:attribute>
						<xsl:attribute name="class">dac-tooltip-reports</xsl:attribute>
						
						<div class="dac-entraid-tooltip-wrapper">
						
							<xsl:if test="$hasExportpdf = 'true'">							
								<div class="dac-entraid-tooltip-reports-row">
									<xsl:attribute name="onClick">
										inchorus.$('<xsl:value-of select="$parentid"/>-export-form').setParameters(
										{
											'uniqueid' : '<xsl:value-of select="$uniqueid"/>',
											'systemid' : '<xsl:value-of select="$systemid"/>',
											'orientation' : 'portrait',
											'exporttype' : 'pdf'
											
										});
										inchorus.$('<xsl:value-of select="$parentid"/>-export-form').submit();
									</xsl:attribute>
									<div class="dac-entraid-reports-pdf" />
									<xsl:value-of select="$inchorus_tooltip_reports_pdf" />
								</div>
							</xsl:if>
							<xsl:if test="$hasExportcsv = 'true'">
									<div class="dac-entraid-tooltip-reports-row-last">
									<xsl:attribute name="onClick">
										inchorus.$('<xsl:value-of select="$parentid"/>-export-form').setParameters(
										{
											'uniqueid' : '<xsl:value-of select="$uniqueid"/>',
											'systemid' : '<xsl:value-of select="$systemid"/>',
											'exporttype' : 'csv'
											
										});
										inchorus.$('<xsl:value-of select="$parentid"/>-export-form').submit();
									</xsl:attribute>
									<div class="dac-entraid-reports-csv" />
									<xsl:value-of select="$inchorus_tooltip_reports_csv" />
								</div>
							</xsl:if>
						</div>
						
					</inchorus-tooltip>
					<inchorus-form>
						<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-export-form</xsl:attribute>
						<xsl:attribute name="submitprefix">inc-</xsl:attribute>
						<xsl:attribute name="responsetype">download</xsl:attribute>
						<xsl:attribute name="hasresponsefile">true</xsl:attribute>
						<xsl:attribute name="command">exportLicenseDetails</xsl:attribute>
					</inchorus-form>
				</xsl:if>
				<xsl:if test="$hasPrint = 'true'">
					<inchorus-button>
						<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-button-print</xsl:attribute>
						<xsl:attribute name="type">icon</xsl:attribute>
						<xsl:attribute name="icon">print</xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="$inchorus_button_print" /></xsl:attribute>
						<xsl:attribute name="highlighting">low</xsl:attribute>
						<xsl:attribute name="active">true</xsl:attribute>
						<xsl:attribute name="border">true</xsl:attribute>
						<xsl:attribute name="hover">true</xsl:attribute>
						<xsl:choose>
							<xsl:when test="$hasExportcsv = 'true' or $hasExportpdf = 'true'">
								<xsl:attribute name="style">float:right;margin-right:15px;</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="style">float:right;margin-right:0px;</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="onclick">
							inchorus.$('<xsl:value-of select="$parentid"/>-print').submit();
						</xsl:attribute>
					</inchorus-button>						
					<inchorus-form>
						<xsl:attribute name="id"><xsl:value-of select="$parentid"/>-print</xsl:attribute>
						<xsl:attribute name="submitprefix">inc-</xsl:attribute>
						<xsl:attribute name="responsetype">tab</xsl:attribute>
						<xsl:attribute name="hasresponsefile">true</xsl:attribute>
						<xsl:attribute name="command">exportLicenseDetails</xsl:attribute>
						<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid"/>"}]</xsl:attribute>
					</inchorus-form>
				</xsl:if>
			</div>
			</xsl:if>
			
			<div class="dac-slider-right-content-wrapper">
				<div class="dac-slider-right-content-buttonbar">
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-license</xsl:attribute>
							<xsl:attribute name="active">true</xsl:attribute>
							<xsl:attribute name="type">icon</xsl:attribute>
							<xsl:attribute name="icon">menu</xsl:attribute>
							<xsl:attribute name="highlighting">high</xsl:attribute>
							<xsl:attribute name="onclick">
								modus = '<xsl:value-of select="$modus" />';
								
								if (modus == 'entraidlicense') {
									inchorus.$('persons-slider-details-left').deactivate();
								}
								
								jQuery('#entraid-slider-details').removeClass('entraid-slider-details-60percent');
								inchorus.$('slider-admin-entraidlicense-details-history').deactivate();
								inchorus.$('slider-admin-entraidlicense-details-license').activate();
								jQuery('#<xsl:value-of select="$parentid" />-button-license').attr('highlighting','high');
								jQuery('#<xsl:value-of select="$parentid" />-button-history').attr('highlighting','low');
							</xsl:attribute>
						</inchorus-button>
						
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-history</xsl:attribute>
							<xsl:attribute name="active">true</xsl:attribute>
							<xsl:attribute name="type">icon</xsl:attribute>
							<xsl:attribute name="icon">history</xsl:attribute>
							<xsl:attribute name="highlighting">low</xsl:attribute>
							<xsl:attribute name="onclick">
								modus = '<xsl:value-of select="$modus" />';
								
								if (modus == 'adlicense') {
									inchorus.$('persons-slider-details-left').deactivate();
								}
								
								inchorus.$('slider-admin-entraidlicense-details-license').deactivate();
								inchorus.$('slider-admin-entraidlicense-details-history').activate();
								jQuery('#<xsl:value-of select="$parentid" />-button-license').attr('highlighting','low');
								jQuery('#<xsl:value-of select="$parentid" />-button-history').attr('highlighting','high');
							</xsl:attribute>
						</inchorus-button>
				</div>

				<inchorus-content>
					<xsl:attribute name="id"><xsl:value-of select="$parentid" />-license</xsl:attribute>
				  	<xsl:attribute name="hascontentfile">true</xsl:attribute>
				  	<xsl:attribute name="active">true</xsl:attribute>
				 	<xsl:attribute name="command">getLicenseDetails</xsl:attribute>
				 	<xsl:attribute name="parameters">[{"uniqueid":"<xsl:value-of select="$uniqueid"/>"}, {"systemid":"<xsl:value-of select="$systemid"/>"}]</xsl:attribute>
				</inchorus-content>
					
				<inchorus-content>
				 	<xsl:attribute name="id"><xsl:value-of select="$parentid" />-history</xsl:attribute>
				 	<xsl:attribute name="hascontentfile">true</xsl:attribute>
				 	<xsl:attribute name="active">false</xsl:attribute>
				 	<xsl:attribute name="command">getDefaultData</xsl:attribute>
				 	<xsl:attribute name="parameters">[{"modus":"<xsl:value-of select="$modus"/>"},{"uniqueid":"<xsl:value-of select="$uniqueid"/>"}, {"systemid":"<xsl:value-of select="$systemid"/>"}]</xsl:attribute>
				</inchorus-content>
			</div>
			</div>
			
			<div class="dac-slider-content-placeholder">
				<div class="dac-slider-content-placeholder-line">
				</div>
			</div>
			
			<div class="dac-slider-content-extension">
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-right</xsl:attribute>
				
				<inchorus-content>
			  		<xsl:attribute name="id"><xsl:value-of select="$parentid" />-history-list-details</xsl:attribute>
			  		<xsl:attribute name="hascontentfile">true</xsl:attribute>
			  		<xsl:attribute name="active">false</xsl:attribute>
			  		<xsl:attribute name="command">getHistoryDetailsById</xsl:attribute>
			  		<xsl:attribute name="style">padding:20px;</xsl:attribute>
				</inchorus-content>
			</div>
		</div>
	</xsl:template>
</xsl:stylesheet>