<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language_webcomponents.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="thisid">slider-admin-entraiduser-details-user-licenses-tree-firstrow</xsl:variable>
		<xsl:variable name="treeprefix">slider-entraiduser-details-user-licenses-tree-firstrow</xsl:variable>
		<xsl:variable name="countentries" select="count(members/member)" />
		<xsl:variable name="user_uniqueid" select="//parameters/parameter[@name='uniqueid']" />

		<xsl:choose>
			<xsl:when test="members/member">
				<xsl:for-each select="members/member">
					<xsl:variable name="position" select="position()" />
					<xsl:variable name="uniqueidlicense" select="licenseuniqueid" />
					<xsl:variable name="uniqueiduser" select="useruniqueid" />
					<xsl:variable name="licencename" select="licencename" />
					<xsl:variable name="serviceplancounts" select="serviceplancounts/serviceplancount/count" />
					<xsl:variable name="disabledplans" select="disabledplans" />
					<xsl:variable name="enabledplans" select="$serviceplancounts - $disabledplans" />
					
					<inchorus-tree-row class="flex-container" style="display: flex; flex-wrap: nowrap;">
						<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-entry</xsl:attribute>		
						
						<inchorus-tree-row-header style="width:180px;min-width:417px;padding: 7px 10px;border-bottom: 0px !important;">
							<xsl:attribute name="backgroundcode"><xsl:value-of select="$countentries" />-<xsl:value-of select="$position" /></xsl:attribute>
							
							<inchorus-tree-button>
							  	<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-button-<xsl:value-of select="$position" /></xsl:attribute>
							  	<xsl:attribute name="type">text</xsl:attribute>
								<xsl:attribute name="text">&#160;</xsl:attribute>
								<xsl:attribute name="class">entraid-tree-icon-license</xsl:attribute>
								<xsl:attribute name="onclick">
									inchorus.$('<xsl:value-of select="$treeprefix" />-position-<xsl:value-of select="$position" />-nextlevel').setParameters(
										{
											uniqueiduser: '<xsl:value-of select="$uniqueiduser"/>',
											uniqueidlicense: '<xsl:value-of select="$uniqueidlicense"/>',
											
										}
									);
									inchorus.$("<xsl:value-of select="$treeprefix" />-button-<xsl:value-of select="$position" />").toggleActive();
									inchorus.$("<xsl:value-of select="$treeprefix" />-position-<xsl:value-of select="$position" />-nextlevel").toggleActive();
								</xsl:attribute>
								<xsl:attribute name="border">false</xsl:attribute>
								<xsl:attribute name="parameters">[{"parentid":"<xsl:value-of select="$user_uniqueid" />"}]</xsl:attribute>
							</inchorus-tree-button>
							
							<div style="cursor:pointer;">
								<xsl:attribute name="onClick">
									$('#' + $('.active_row').attr("id")).removeClass('active_row');
									$('#' + $(this).parent().parent().attr('id')).addClass('active_row');
								</xsl:attribute>
								<div class="rowname" style="padding-left:0px;color:#666 !important;">
									<div class="msfileserver-tree-icon msfileserver-tree-icon-server" />
									<b><xsl:value-of select="$licencename" /></b>
								</div>
							</div>
	
						</inchorus-tree-row-header>
						
						<inchorus-tree-row-content style="min-width:0px;overflow:hidden;color:#666 !important;padding: 7px 0px;cursor:pointer;width:75px;text-align: right;margin-right:22px;">
							<xsl:value-of select="$enabledplans" />/<xsl:value-of select="$serviceplancounts" />
						</inchorus-tree-row-content>
					</inchorus-tree-row>

					<inchorus-tree-row-nextlevel style="overflow:hidden; height:auto;">
						<xsl:attribute name="id"><xsl:value-of select="$treeprefix" />-position-<xsl:value-of select="$position" />-nextlevel</xsl:attribute>
						<xsl:attribute name="active">false</xsl:attribute>
						<xsl:attribute name="hascontentfile">true</xsl:attribute>
						<xsl:attribute name="alternativecontentfile">slider-admin-entraiduser-details-user-licenses-tree-nextrow</xsl:attribute>
						<xsl:attribute name="activationcontentmode">always</xsl:attribute>
						<xsl:attribute name="deactivationcontentmode">remove</xsl:attribute>
						<xsl:attribute name="parameters">[{"uniqueiduser":"<xsl:value-of select="$uniqueiduser" />"},{"uniqueidlicense":"<xsl:value-of select="$uniqueidlicense" />"}]</xsl:attribute>
						<xsl:attribute name="command">getEntraIDServicePlansForUserByLicense</xsl:attribute>
					</inchorus-tree-row-nextlevel>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<inchorus-message>
					<xsl:attribute name="id">noresults</xsl:attribute>
					<xsl:attribute name="active">true</xsl:attribute>
					<xsl:attribute name="type">node</xsl:attribute>
					<xsl:value-of select="$entraid_license_details_membership_noresult"/>
				</inchorus-message>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>