<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity 
*												
*	Copyright (c) G+H Systems GmbH, 2014
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
		<xsl:variable name="parentid">slider-systemdetails-details</xsl:variable>
		<xsl:variable name="systemid" select="systems/system/systemid" />
		<xsl:variable name="systemname" select="systems/system/name" />
		<xsl:variable name="description" select="systems/system/description" />
		<xsl:variable name="description_count" select="string-length($description)" />
		<xsl:variable name="systemtype" select="//data/parameters/parameter[@name='systemtype']" />
		<xsl:variable name="integrationpackagestatus" select="//data/parameters/parameter[@name='integrationpackagestatus']" />
		<xsl:variable name="collectorenginestatus" select="//data/parameters/parameter[@name='collectorenginestatus']" />
		<xsl:variable name="count_scheduled" select="//data/systems/collectorstatistic/count_scheduled" />
		<xsl:variable name="count_running" select="//data/systems/collectorstatistic/count_running" />
		<xsl:variable name="count_error" select="//data/systems/collectorstatistic/count_error" />
		<xsl:variable name="laststarttime" select="//data/systems/collectorstatistic/laststarttime" />
		<xsl:variable name="nextstarttime" select="//data/systems/collectorstatistic/nextstarttime" />
		<xsl:variable name="lastruntime_days" select="//data/systems/collectorstatistic/lastruntime_days" />
		<xsl:variable name="lastruntime_hours" select="//data/systems/collectorstatistic/lastruntime_hours" />
		<xsl:variable name="lastruntime_minutes" select="//data/systems/collectorstatistic/lastruntime_minutes" />
		<xsl:variable name="lastruntime_seconds" select="//data/systems/collectorstatistic/lastruntime_seconds" />
		<xsl:variable name="lastnodecounttotal" select="//data/systems/collectorstatistic/lastnodecounttotal" />
			
  <inchorus-button>
  	<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-options</xsl:attribute>
    <xsl:attribute name="type">text</xsl:attribute>
    <xsl:attribute name="text">...</xsl:attribute>
    <xsl:attribute name="style">position:relative;margin-top: -54px;float:right;margin-right:0px;background-color: transparent;border-radius: 0.4em;padding:4px 10px;text-align:center;</xsl:attribute>
    <xsl:attribute name="onclick">
		inchorus.$('<xsl:value-of select="$parentid" />-tooltip-options').activate();
    </xsl:attribute>
  </inchorus-button>

  
  <inchorus-tooltip>
  	<xsl:attribute name="id"><xsl:value-of select="$parentid" />-tooltip-options</xsl:attribute>
    <xsl:attribute name="position">bottom-left</xsl:attribute>
    <xsl:attribute name="closeonoutsideclick">true</xsl:attribute>
    <xsl:attribute name="hascontentfile">false</xsl:attribute>
    <xsl:attribute name="active">false</xsl:attribute>
    <xsl:attribute name="linkedpointerid"><xsl:value-of select="$parentid" />-button-options</xsl:attribute>
    <xsl:attribute name="linkedpointertype">arrow</xsl:attribute>
   
    <div style="padding:10px 10px;height:99px;">
    	 <div class="dac-system-tooltip-options-row" style="border-bottom: 1px dotted silver;height:auto;overflow:hidden;">
			<xsl:choose>
				<xsl:when test="$integrationpackagestatus = 'READY' and $collectorenginestatus != 'ERROR_CE_UNREACHABLE'">
					<xsl:attribute name="style">border-bottom: 1px dotted silver;height:auto;overflow:hidden;</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="style">border-bottom: 1px dotted silver;height:auto;overflow:hidden;opacity:0.5;</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>	
					
			
			
			<inchorus-button class="dac-system-box-button-changefile">
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-editsystem</xsl:attribute>
				<xsl:attribute name="type">icontext</xsl:attribute>
				<xsl:attribute name="icon">edit</xsl:attribute>
				<xsl:if test="$count_running &gt; 0">
					<xsl:attribute name="status">disabled</xsl:attribute>
				</xsl:if>
				<xsl:attribute name="text"><xsl:value-of select="$entraid_button_editsystem" /></xsl:attribute>
				<xsl:attribute name="highlighting">low</xsl:attribute>
				<xsl:attribute name="style">background-color:transparent;border:0px;width:calc(100% - 25px);</xsl:attribute>
				<xsl:if test="$integrationpackagestatus = 'READY' and $collectorenginestatus != 'ERROR_CE_UNREACHABLE'">
					<xsl:attribute name="onclick">
						inchorus.$('slider-systemdetails-lightbox-editsystem').setParameters(
								{
									"systemid":"<xsl:value-of select="$systemid"/>",
									"systemname":"<xsl:value-of select="$systemname"/>",
									"systemtype":"<xsl:value-of select="$systemtype"/>",
									"header":"<xsl:value-of select="$systemname"/>",
								}
						);
						inchorus.$('slider-systemdetails-lightbox-editsystem').setCommand('getSystem');
						inchorus.$('slider-systemdetails-lightbox-editsystem').activate();
					</xsl:attribute>
				</xsl:if>
			</inchorus-button>
    	</div>
    	<!-- 
    	<div class="dac-system-tooltip-options-row" style="border-bottom: 1px dotted silver;height:auto;overflow:hidden;">
			<inchorus-button class="dac-system-box-button-changefile">
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-export</xsl:attribute>
				<xsl:attribute name="type">icontext</xsl:attribute>
				<xsl:attribute name="icon">download</xsl:attribute>
				<xsl:if test="$count_running &gt; 0">
					<xsl:attribute name="status">disabled</xsl:attribute>
				</xsl:if>
				<xsl:attribute name="text"><xsl:value-of select="$entraid_button_export" /></xsl:attribute>
				<xsl:attribute name="highlighting">low</xsl:attribute>
				<xsl:attribute name="style">background-color:transparent;border:0px;width:calc(100% - 25px);</xsl:attribute>
				<xsl:attribute name="onclick">
						inchorus.$('slider-systemdetails-lightbox-export').setAlternativecontentfile('slider-systemdetails-lightbox-export');
						inchorus.$('slider-systemdetails-lightbox-export').setParameters(
							{
								"systemid":"<xsl:value-of select="$systemid"/>",
								"systemname":"<xsl:value-of select="$systemname"/>",
								"systemtype":"<xsl:value-of select="$systemtype"/>"
							}
						);
						inchorus.$('slider-systemdetails-lightbox-export').setCommand('getDefaultData');
						inchorus.$('slider-systemdetails-lightbox-export').activate();
						
						jQuery('#slider-systemdetails-lightbox-export').attr('class','');
						jQuery('#slider-systemdetails-lightbox-export').addClass('export');
					</xsl:attribute>
			</inchorus-button>
    	</div>
    	-->
    	<div class="dac-system-tooltip-options-row" style="border-bottom: 1px dotted silver;height:auto;overflow:hidden;">
			<inchorus-button class="dac-system-box-button-changefile">
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-deletedata</xsl:attribute>
				<xsl:attribute name="type">icontext</xsl:attribute>
				<xsl:attribute name="icon">delete</xsl:attribute>
				<xsl:if test="$count_running &gt; 0">
					<xsl:attribute name="status">disabled</xsl:attribute>
				</xsl:if>
				<xsl:attribute name="text"><xsl:value-of select="$entraid_button_deletedata" /></xsl:attribute>
				<xsl:attribute name="highlighting">low</xsl:attribute>
				<xsl:attribute name="style">background-color:transparent;border:0px;width:calc(100% - 25px);</xsl:attribute>
				<xsl:attribute name="onclick">
					jQuery('#slider-systemdetails-lightbox-validation').attr('class','deletedata');
					inchorus.$('slider-systemdetails-lightbox-validation').setAlternativecontentfile('slider-systemdetails-lightbox-validation-deletedata');
					inchorus.$('slider-systemdetails-lightbox-validation').setParameters(
						{
							"systemid":"<xsl:value-of select="$systemid"/>"
						}
					);
					inchorus.$('slider-systemdetails-lightbox-validation').activate();
				</xsl:attribute>
			</inchorus-button>
    	</div>
    	<div class="dac-system-tooltip-options-row" style="border-bottom: 0px dotted silver;height:auto;overflow:hidden;">
			<inchorus-button class="dac-system-box-button-changefile">
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-button-deletesystem</xsl:attribute>
				<xsl:attribute name="type">icontext</xsl:attribute>
				<xsl:attribute name="icon">delete</xsl:attribute>
				<xsl:if test="$count_running &gt; 0">
					<xsl:attribute name="status">disabled</xsl:attribute>
				</xsl:if>
				<xsl:attribute name="text"><xsl:value-of select="$entraid_button_deletesystem" /></xsl:attribute>
				<xsl:attribute name="highlighting">low</xsl:attribute>
				<xsl:attribute name="style">background-color:transparent;border:0px;width:calc(100% - 25px);</xsl:attribute>
			    <xsl:attribute name="onclick">
			    	jQuery('#slider-systemdetails-lightbox-validation').attr('class','deletesystemanddata');
					inchorus.$('slider-systemdetails-lightbox-validation').setAlternativecontentfile('slider-systemdetails-lightbox-validation-delete-systemanddata');
					inchorus.$('slider-systemdetails-lightbox-validation').setParameters(
						{
							"systemid":"<xsl:value-of select="$systemid"/>"
						}
					);
					inchorus.$('slider-systemdetails-lightbox-validation').activate();
				</xsl:attribute>
			</inchorus-button>
    	</div>
    </div>
  </inchorus-tooltip>
 
			
			<inchorus-button>
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-collectall</xsl:attribute>
				<xsl:attribute name="type">icontext</xsl:attribute>
				<xsl:attribute name="icon">start</xsl:attribute>
				<xsl:if test="$count_running &gt; 0">
					<xsl:attribute name="status">disabled</xsl:attribute>
				</xsl:if>
				<xsl:attribute name="text"><xsl:value-of select="$entraid_button_collectall" /></xsl:attribute>
				<xsl:choose>
					<xsl:when test="$integrationpackagestatus = 'READY' and $collectorenginestatus != 'ERROR_CE_UNREACHABLE'">
						<xsl:attribute name="style">float:right;margin-right:49px;margin-top:-54px;border-radius: 0.4em;border-color: #dddddd;background-color:#fff;</xsl:attribute>
						<xsl:attribute name="onclick">
							jQuery('#slider-systemdetails-lightbox-validation').attr('class','collectall');
							inchorus.$('slider-systemdetails-lightbox-validation').setAlternativecontentfile('slider-systemdetails-lightbox-validation-collectall');
							inchorus.$('slider-systemdetails-lightbox-validation').setParameters(
								{
									"systemid":"<xsl:value-of select="$systemid"/>"
								}
							);
							inchorus.$('slider-systemdetails-lightbox-validation').activate();
						</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="style">margin-right:49px;margin-top: -54px;float: right;border-radius: 0.4em;border-color: #dddddd;background-color:#fff;cursor:not-allowed;opacity: 0.5;</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</inchorus-button>

		<xsl:if test="$integrationpackagestatus != 'READY'">
			<inchorus-message>
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-message-ceunreachable</xsl:attribute>
				<xsl:attribute name="type">error</xsl:attribute>
				<xsl:attribute name="active">true</xsl:attribute>
				<b><xsl:value-of select="$entraid_message_error_connector_notready_attention" /></b>&#160;<xsl:value-of select="$entraid_message_error_connector_notready" />
			</inchorus-message>
		</xsl:if>

		<xsl:if test="$collectorenginestatus = 'ERROR_CE_UNREACHABLE'">
			<inchorus-message>
				<xsl:attribute name="id"><xsl:value-of select="$parentid" />-message</xsl:attribute>
				<xsl:attribute name="type">error</xsl:attribute>
				<xsl:attribute name="active">true</xsl:attribute>
				<b><xsl:value-of select="$entraid_message_error_connector_ceunreachable_attention" /></b>&#160;<xsl:value-of select="$entraid_message_error_connector_ceunreachable" />
			</inchorus-message>
		</xsl:if>		
		<inchorus-list id="lightbox-system-list" active="true">
			<inchorus-list-content style="min-height:50px;height:270px;">
				<inchorus-list-content-row>
				   <div style="width: 60%;padding-left: 12px;">
				   		<xsl:value-of select="$entraid_slider_details_name" />
				   </div>
				   <div style="width: 40%;">
				   		<xsl:value-of select="$systemname" />
				   </div>
			   </inchorus-list-content-row>
			   <inchorus-list-content-row>
				   <div style="width: 60%;padding-left: 12px;">
				   		<xsl:value-of select="$entraid_slider_details_numberofobjects" />
				   </div>
				   <div style="width: 40%;">
				   		<xsl:value-of select="$lastnodecounttotal" />
				   </div>
			   </inchorus-list-content-row>
			   <inchorus-list-content-row>
					<div style="width: 60%;padding-left: 12px;">
				    	<xsl:value-of select="$entraid_slider_details_status" />
				    </div>
				    <div style="width: 40%;">
				    	<xsl:attribute name="id"><xsl:value-of select="$parentid" />-status</xsl:attribute>
				        	
				        <xsl:choose>
				         	<xsl:when test="$laststarttime = ''">
				               	<b class="textcolor_grey"><xsl:value-of select="$entraid_slider_details_status_neverread" /></b>
				            </xsl:when>
				            <xsl:when test="$count_running &gt; '0'">
				              	<b class="textcolor_yellow"><xsl:value-of select="$entraid_slider_details_status_isrunning" /></b>
				            </xsl:when>
				            <xsl:when test="$count_error &gt; '0'">
				              	<b class="textcolor_red"><xsl:value-of select="$entraid_slider_details_status_error" /></b>
				            </xsl:when>
				          	<xsl:otherwise>
				          		<b class="textcolor_green"><xsl:value-of select="$entraid_slider_details_status_success" /></b>
				           	</xsl:otherwise>
				        </xsl:choose>
				    </div>
				</inchorus-list-content-row>
				<inchorus-list-content-row>
				   <div style="width: 60%;padding-left: 12px;">
				   		<xsl:value-of select="$entraid_slider_details_laststart" />
				   </div>
				   <div style="width: 40%;">
						<xsl:choose>
							<xsl:when test="'<!--GADGET:LANGUAGE-->' = 'de'">
								<xsl:value-of select="substring($laststarttime,9,2)"/>.<xsl:value-of select="substring($laststarttime,6,2)"/>.<xsl:value-of select="substring($laststarttime,1,4)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="substring($laststarttime,1,4)"/>-<xsl:value-of select="substring($laststarttime,6,2)"/>-<xsl:value-of select="substring($laststarttime,9,2)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
							</xsl:otherwise>
						</xsl:choose>
				   </div>
			   </inchorus-list-content-row>
			   <inchorus-list-content-row>
				   <div style="width: 60%;padding-left: 12px;">
				   		<xsl:value-of select="$entraid_slider_details_lastruntime" />
				   </div>
				   <div style="width: 40%;">
				   		<xsl:choose>
							<xsl:when test="$lastruntime_days &gt; '0'">
								<xsl:value-of select="$lastruntime_days" />&#160;<xsl:value-of select="$entraid_days" />&#160;<xsl:value-of select="$lastruntime_hours" />&#160;<xsl:value-of select="$entraid_hours" />&#160;<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$entraid_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$entraid_seconds" /><br/>
							</xsl:when>
							<xsl:when test="$lastruntime_hours &gt; '0'">
								<xsl:value-of select="$lastruntime_hours" />&#160;<xsl:value-of select="$entraid_hours" />&#160;<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$entraid_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$entraid_seconds" /><br/>
							</xsl:when>
							<xsl:when test="$lastruntime_minutes &gt; '0'">
								<xsl:value-of select="$lastruntime_minutes" />&#160;<xsl:value-of select="$entraid_minutes" />&#160;<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$entraid_seconds" /><br/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$lastruntime_seconds" />&#160;<xsl:value-of select="$entraid_seconds" /><br/>
							</xsl:otherwise>
						</xsl:choose>
				   </div>
			   </inchorus-list-content-row>
			   <inchorus-list-content-row>
				   <div style="width: 60%;padding-left: 12px;">
				   		<xsl:value-of select="$entraid_slider_details_nextstart" />
				   </div>
				   <div style="width: 40%;">
				   		<xsl:choose>
							<xsl:when test="'<!--GADGET:LANGUAGE-->' = 'de'">
								<xsl:value-of select="substring($nextstarttime,9,2)"/>.<xsl:value-of select="substring($nextstarttime,6,2)"/>.<xsl:value-of select="substring($nextstarttime,1,4)"/>&#160;<xsl:value-of select="substring($nextstarttime,12,8)"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="substring($nextstarttime,1,4)"/>-<xsl:value-of select="substring($nextstarttime,6,2)"/>-<xsl:value-of select="substring($nextstarttime,9,2)"/>&#160;<xsl:value-of select="substring($laststarttime,12,8)"/>
							</xsl:otherwise>
						</xsl:choose>
				   </div>
			   </inchorus-list-content-row>
			</inchorus-list-content>
		</inchorus-list>
	</xsl:template>
</xsl:stylesheet>