<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity
*	05/01/2020	Thomas Gertler  	2.1.0		compatible to framework version 2.1 
*												
*	Copyright (c) G+H Systems GmbH, 2020
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language-webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->
	
	<xsl:template match="data">
	
		<xsl:variable name="thisid"><xsl:value-of select="$contentid"/>-login</xsl:variable> 
		<!-- id of this page. will be used later to make the elements inside and their id's independent from the page's id -->

		<html>
			<head>
				<title>
					<xsl:value-of select="$login_headline" /> - <xsl:value-of select="$gadgetname" />
				</title>
				<!-- jquery -->
				<script src="inc/js/jquery/jquery.js" type="text/javascript"/>
			
				<!-- inchorus standard -->	
				<script src="inc/js/inchorus/inchorus.gadget.js" type="text/javascript"/>
				<link media="screen" rel="stylesheet" type="text/css" href="inc/css/inchorus/inchorus.gadget.css" />
			
				<!-- webcomponents in dependency of browser -->
				<script type="text/javascript" src="inc/js/webcomponents/polyfills/webcomponents-loader.js"></script>
				<script>
					var ua = window.navigator.userAgent;
					var msie = ua.indexOf("MSIE ");
					var script = 'inc/js/webcomponents/inchorus-webcomponents.js';
					if (msie > 0 || !!navigator.userAgent.match(/Trident.*rv\:11\./)) {
						script = 'inc/js/webcomponents/inchorus-webcomponents-ie11.js';
					}
					var s = document.createElement('script');
	            	s.src = script;
	            	document.head.appendChild(s);
				</script>
				
				<script src="inc/js/inchorus.{$gadgetname}.js" type="text/javascript"/>
				<link media="screen" rel="stylesheet" type="text/css" href="inc/css/inchorus.{$gadgetname}.css" />
				
				<style>
					.login-message div { 
						margin: 0px 0px 20px 0px !important;
					}
				</style>					
			</head>
			<body>			

				<inchorus-gadget>
				 	<xsl:attribute name="id">1</xsl:attribute>
					<xsl:attribute name="version">1.0.1</xsl:attribute>
 					<xsl:attribute name="path">/<xsl:value-of select="$gadgetpath"/></xsl:attribute>					
			
					<form style="width:300px;padding:20px;overflow:hidden;margin-left:auto;margin-right:auto;margin-top:14%;border: 1px solid #ddd;border-radius: 0.4em;">
						<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-form-1</xsl:attribute>
						<xsl:attribute name="method">POST</xsl:attribute>
						<xsl:attribute name="action">/<xsl:value-of select="$gadgetpath"/><xsl:value-of select="$requestpath"/></xsl:attribute>
						<img src="inc/img/inchorus-logo.png" style="height:auto;display: block;margin-left: auto;margin-right: auto;margin-bottom:20px;" />

						<xsl:if test="$statustype = 'error' ">						
							<inchorus-message class="login-message">
								<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-message-1</xsl:attribute>
          						<xsl:attribute name="type">error</xsl:attribute>
           						<!--GADGET:VALUE-OF:STATUSCODE-->
       					 	</inchorus-message>							
						</xsl:if>

						<div><xsl:value-of select="$login_username"/>:</div>
						<input>
							<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-input-username</xsl:attribute>
							<xsl:attribute name="type">text</xsl:attribute>
							<xsl:attribute name="name">username</xsl:attribute>							
						</input>
						<div><xsl:value-of select="$login_password"/>:</div>
						<input>
							<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-input-password</xsl:attribute>
							<xsl:attribute name="type">password</xsl:attribute>
							<xsl:attribute name="name">password</xsl:attribute>							
						</input>
			
						<inchorus-button>
							<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-button-1</xsl:attribute>
					        <xsl:attribute name="type">text</xsl:attribute>
					        <xsl:attribute name="highlighting">medium</xsl:attribute>
					        <xsl:attribute name="text"><xsl:value-of select="$login_button"/></xsl:attribute>
					        <xsl:attribute name="onclick">document.getElementById("<xsl:value-of select="$thisid"/>-form-1").submit();</xsl:attribute>
						</inchorus-button>
					</form>
				</inchorus-gadget>
				<script>				
					$("#<xsl:value-of select="$thisid"/>-input-username").focus();
				
					$("#<xsl:value-of select="$thisid"/>-form-1").find('input').keypress(function(e) {
	 					if(e.which == 10 || e.which == 13) {
		 					$('#<xsl:value-of select="$thisid"/>-form-1').submit();
	 					}
					});
				</script>
			</body>
		</html>
	</xsl:template>
	
</xsl:stylesheet>