<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity
*	05/01/2020	Thomas Gertler  	2.1.0		compatible to framework version 2.1 
*												
*	Copyright (c) G+H Systems GmbH, 2020
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language-webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->

	<xsl:template match="data">
	
		<xsl:variable name="thisid"><xsl:value-of select="$contentid"/>-index</xsl:variable> 
		<!-- id of this page. will be used later to make the elements inside and their id's independent from the page's id -->
		
		<xsl:variable name="parametersjsontemp"><xsl:for-each select="//data/parameters/parameter">{"<xsl:value-of select="@name"/>":"<xsl:value-of select="text()"/>"},</xsl:for-each></xsl:variable>
		<xsl:variable name="parametersjson">[<xsl:value-of select="substring($parametersjsontemp, 1, string-length($parametersjsontemp)-1)" />]</xsl:variable>
		<!-- we generate the given parameters to a json strign to hand it over to the integrationmode of the gadget -->
	
		<html>
			<head>
				<title>
					<xsl:value-of select="$gadgetname" />
				</title>
				<!-- jquery -->
				<script src="inc/js/jquery/jquery.js" type="text/javascript"/>
			
				<!-- inchorus standard -->	
				<script src="inc/js/inchorus/inchorus.gadget.js" type="text/javascript"/>
				<link media="screen" rel="stylesheet" type="text/css" href="inc/css/inchorus/inchorus.gadget.css" />
			
				<!-- webcomponents in dependency of browser -->
				<script type="text/javascript" src="inc/js/webcomponents/polyfills/webcomponents-loader.js"></script>
				<script>
					var ua = window.navigator.userAgent;
					var msie = ua.indexOf("MSIE ");
					var script = 'inc/js/webcomponents/inchorus-webcomponents.js';
					if (msie > 0 || !!navigator.userAgent.match(/Trident.*rv\:11\./)) {
						script = 'inc/js/webcomponents/inchorus-webcomponents-ie11.js';
					}
					var s = document.createElement('script');
	            	s.src = script;
	            	document.head.appendChild(s);
				</script>
				
				<script src="inc/js/inchorus.{$gadgetname}.js" type="text/javascript"/>
				<link media="screen" rel="stylesheet" type="text/css" href="inc/css/inchorus.{$gadgetname}.smartphone.css" />
				
				<!-- tag to set display size on android -->
				<meta name="viewport" content="width=device-width, height=device-height" />
			</head>
			<body>
			
				<inchorus-gadget>
 					<xsl:attribute name="id">-1</xsl:attribute>
					<xsl:attribute name="version">1.0.1</xsl:attribute>
 					<xsl:attribute name="path">/<xsl:value-of select="$gadgetpath"/></xsl:attribute>
					
					<inchorus-pages>
						<xsl:attribute name="activepageid">page-index</xsl:attribute>
						
						<inchorus-page>
							<xsl:attribute name="id">page-index</xsl:attribute>
							<xsl:attribute name="hascontentfile">true</xsl:attribute>				
						</inchorus-page>
											
					</inchorus-pages>			
					
				</inchorus-gadget>
				
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>