<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
*
*	Date 	    Programmer		 Version		Description
*	~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*	07/30/2014	Sebastian Radau  	1.0.0		Created 
*	12/20/2016	Thomas Gertler  	1.1.0		webcomponents compatiblity
*	05/01/2020	Thomas Gertler  	2.1.0		compatible to framework version 2.1 
*												
*	Copyright (c) G+H Systems GmbH, 2020
*	
*	This development kit is proprietary to G+H Systems GmbH.	
*	All rights reserved. For more information visit the website:
*   www.inchorus.de	
*							
*************************************************************************/-->

	<!-- Output Definition - Beginning -->
	<xsl:output method="html" encoding="<!--GADGET:ENCODING-->" />	
	<!-- Output Definition - End -->

	<!-- Language File Include - Beginning -->
	<xsl:include href="<!--GADGET:LANGUAGE-->/language.xsl" />
	<xsl:include href="<!--GADGET:LANGUAGE-->/language-webcomponents.xsl" />
	<!-- Language File Include - End -->
	
	<!-- Gadget Variables File Include - Beginning -->
	<xsl:include href="gadget_variables.xsl" />
	<!-- Gadget Variables File Include - End -->

	<xsl:template match="data">
	
		<xsl:variable name="thisid"><xsl:value-of select="$contentid"/>-login</xsl:variable> 
		<!-- id of this page. will be used later to make the elements inside and their id's independent from the page's id -->
		
		<html>
			<head>
				<title>
					<xsl:value-of select="$gadgetname" />
				</title>
				<!-- jquery -->
				<script src="inc/js/jquery/jquery.js" type="text/javascript"/>
			
				<!-- inchorus standard -->	
				<script src="inc/js/inchorus/inchorus.gadget.js" type="text/javascript"/>
				<link media="screen" rel="stylesheet" type="text/css" href="inc/css/inchorus/inchorus.gadget.css" />
			
				<!-- webcomponents in dependency of browser -->
				<script type="text/javascript" src="inc/js/webcomponents/polyfills/webcomponents-loader.js"></script>
				<script>
					var ua = window.navigator.userAgent;
					var msie = ua.indexOf("MSIE ");
					var script = 'inc/js/webcomponents/inchorus-webcomponents.js';
					if (msie > 0 || !!navigator.userAgent.match(/Trident.*rv\:11\./)) {
						script = 'inc/js/webcomponents/inchorus-webcomponents-ie11.js';
					}
					var s = document.createElement('script');
	            	s.src = script;
	            	document.head.appendChild(s);
				</script>
				
				<script src="inc/js/inchorus.{$gadgetname}.js" type="text/javascript"/>
				<link media="screen" rel="stylesheet" type="text/css" href="inc/css/inchorus.{$gadgetname}.smartphone.css" />
				
				<!-- tag to set display size on android -->
				<meta name="viewport" content="width=device-width, height=device-height" />
			</head>
			<body>
			
				<inchorus-gadget>
 					<xsl:attribute name="id">-1</xsl:attribute>
					<xsl:attribute name="version">1.0.1</xsl:attribute>
 					<xsl:attribute name="path">/<xsl:value-of select="$gadgetpath"/></xsl:attribute>

					<inchorus-pages>
						<xsl:attribute name="activepageid"><xsl:value-of select="$thisid"/>-page-login</xsl:attribute>
						
						<inchorus-page>
							<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-page-login</xsl:attribute>
							
							<inchorus-page-header>
								<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-pages-page-1-header</xsl:attribute>
								<h1><xsl:value-of select="$gadgetname" /></h1>
							</inchorus-page-header>
					
							<inchorus-page-content>
								<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-pages-page-1-content</xsl:attribute>
								<xsl:attribute name="padding">true</xsl:attribute>					
								<br/><br/>
								<img src="inc/img/inchorus-logo.png" style="height:auto;display: block;margin-left: auto;margin-right: auto;" />						
								<br/><br/>
								<form>
									<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-form-1</xsl:attribute>
									<xsl:attribute name="method">POST</xsl:attribute>
									<xsl:attribute name="action">/<xsl:value-of select="$gadgetpath"/><xsl:value-of select="$requestpath"/></xsl:attribute>
					
									<xsl:if test="$statustype = 'error' ">
									
										<inchorus-message>
											<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-message-1</xsl:attribute>
					        				<xsl:attribute name="type">error</xsl:attribute>
					        				<p style="margin-top:5px;margin-bottom:0px;"><!--GADGET:VALUE-OF:STATUSCODE--></p>
					     				</inchorus-message>
					     				
									</xsl:if>
					
									<div style="margin-top:15px;"><xsl:value-of select="$login_username"/>:</div>
									<input>
										<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-input-username</xsl:attribute>
										<xsl:attribute name="type">text</xsl:attribute>
										<xsl:attribute name="name">username</xsl:attribute>							
									</input>
									<div><xsl:value-of select="$login_password"/>:</div>
									<input>
										<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-input-password</xsl:attribute>
										<xsl:attribute name="type">password</xsl:attribute>
										<xsl:attribute name="name">password</xsl:attribute>							
									</input>
								</form>

								<inchorus-button>
									<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-button-1</xsl:attribute>
							        <xsl:attribute name="type">text</xsl:attribute>
							        <xsl:attribute name="highlighting">medium</xsl:attribute>
							        <xsl:attribute name="fullwidth">true</xsl:attribute>
							        <xsl:attribute name="text"><xsl:value-of select="$login_button"/></xsl:attribute>
							        <xsl:attribute name="style">margin-top:5px;</xsl:attribute>
							        <xsl:attribute name="onclick">document.getElementById("<xsl:value-of select="$thisid"/>-form-1").submit();</xsl:attribute>

								</inchorus-button>
								
							</inchorus-page-content>
							
							<inchorus-page-footer>
								<xsl:attribute name="id"><xsl:value-of select="$thisid"/>-pages-page-1-footer</xsl:attribute>
								<xsl:value-of select="$lbl_gadgetversion" />&#160;<xsl:value-of select="$gadgetversion" />
							</inchorus-page-footer>
							
							<script>
								$("#<xsl:value-of select="$thisid"/>-input-username").focus();
							</script>
							
						</inchorus-page>
											
					</inchorus-pages>

				</inchorus-gadget>
				
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>